/* This file is auto-generated by opth-gen.awk.  */

#ifndef OPTIONS_H
#define OPTIONS_H

#include "flag-types.h"

#if !defined(IN_LIBGCC2) && !defined(IN_TARGET_LIBS) && !defined(IN_RTS)
#ifndef GENERATOR_FILE
#if !defined(GCC_DRIVER) && !defined(IN_LIBGCC2) && !defined(IN_TARGET_LIBS)
struct GTY(()) gcc_options
#else
struct gcc_options
#endif
{
#endif
#ifdef GENERATOR_FILE
extern HOST_WIDE_INT frame_larger_than_size;
#else
  HOST_WIDE_INT x_frame_larger_than_size;
#define frame_larger_than_size global_options.x_frame_larger_than_size
#endif
#ifdef GENERATOR_FILE
extern HOST_WIDE_INT larger_than_size;
#else
  HOST_WIDE_INT x_larger_than_size;
#define larger_than_size global_options.x_larger_than_size
#endif
#ifdef GENERATOR_FILE
extern bool exit_after_options;
#else
  bool x_exit_after_options;
#define exit_after_options global_options.x_exit_after_options
#endif
#ifdef GENERATOR_FILE
extern bool flag_dump_all_passed;
#else
  bool x_flag_dump_all_passed;
#define flag_dump_all_passed global_options.x_flag_dump_all_passed
#endif
#ifdef GENERATOR_FILE
extern bool flag_opts_finished;
#else
  bool x_flag_opts_finished;
#define flag_opts_finished global_options.x_flag_opts_finished
#endif
#ifdef GENERATOR_FILE
extern bool flag_warn_unused_result;
#else
  bool x_flag_warn_unused_result;
#define flag_warn_unused_result global_options.x_flag_warn_unused_result
#endif
#ifdef GENERATOR_FILE
extern bool use_gnu_debug_info_extensions;
#else
  bool x_use_gnu_debug_info_extensions;
#define use_gnu_debug_info_extensions global_options.x_use_gnu_debug_info_extensions
#endif
#ifdef GENERATOR_FILE
extern bool warn_frame_larger_than;
#else
  bool x_warn_frame_larger_than;
#define warn_frame_larger_than global_options.x_warn_frame_larger_than
#endif
#ifdef GENERATOR_FILE
extern bool warn_larger_than;
#else
  bool x_warn_larger_than;
#define warn_larger_than global_options.x_warn_larger_than
#endif
#ifdef GENERATOR_FILE
extern char *help_enum_printed;
#else
  char * x_help_enum_printed;
#define help_enum_printed global_options.x_help_enum_printed
#endif
#ifdef GENERATOR_FILE
extern char *help_printed;
#else
  char * x_help_printed;
#define help_printed global_options.x_help_printed
#endif
#ifdef GENERATOR_FILE
extern const char *main_input_basename;
#else
  const char * x_main_input_basename;
#define main_input_basename global_options.x_main_input_basename
#endif
#ifdef GENERATOR_FILE
extern const char *main_input_filename;
#else
  const char * x_main_input_filename;
#define main_input_filename global_options.x_main_input_filename
#endif
#ifdef GENERATOR_FILE
extern enum debug_info_levels debug_info_level;
#else
  enum debug_info_levels x_debug_info_level;
#define debug_info_level global_options.x_debug_info_level
#endif
#ifdef GENERATOR_FILE
extern enum debug_info_type write_symbols;
#else
  enum debug_info_type x_write_symbols;
#define write_symbols global_options.x_write_symbols
#endif
#ifdef GENERATOR_FILE
extern enum debug_struct_file debug_struct_generic[DINFO_USAGE_NUM_ENUMS];
#else
  enum debug_struct_file x_debug_struct_generic[DINFO_USAGE_NUM_ENUMS];
#define debug_struct_generic global_options.x_debug_struct_generic
#endif
#ifdef GENERATOR_FILE
extern enum debug_struct_file debug_struct_ordinary[DINFO_USAGE_NUM_ENUMS];
#else
  enum debug_struct_file x_debug_struct_ordinary[DINFO_USAGE_NUM_ENUMS];
#define debug_struct_ordinary global_options.x_debug_struct_ordinary
#endif
#ifdef GENERATOR_FILE
extern enum graph_dump_types graph_dump_format;
#else
  enum graph_dump_types x_graph_dump_format;
#define graph_dump_format global_options.x_graph_dump_format
#endif
#ifdef GENERATOR_FILE
extern enum stack_check_type flag_stack_check;
#else
  enum stack_check_type x_flag_stack_check;
#define flag_stack_check global_options.x_flag_stack_check
#endif
#ifdef GENERATOR_FILE
extern enum vect_verbosity_levels user_vect_verbosity_level;
#else
  enum vect_verbosity_levels x_user_vect_verbosity_level;
#define user_vect_verbosity_level global_options.x_user_vect_verbosity_level
#endif
#ifdef GENERATOR_FILE
extern int *param_values;
#else
  int * x_param_values;
#define param_values global_options.x_param_values
#endif
#ifdef GENERATOR_FILE
extern int flag_complex_method;
#else
  int x_flag_complex_method;
#define flag_complex_method global_options.x_flag_complex_method
#endif
#ifdef GENERATOR_FILE
extern int flag_debug_asm;
#else
  int x_flag_debug_asm;
#define flag_debug_asm global_options.x_flag_debug_asm
#endif
#ifdef GENERATOR_FILE
extern int flag_dump_rtl_in_asm;
#else
  int x_flag_dump_rtl_in_asm;
#define flag_dump_rtl_in_asm global_options.x_flag_dump_rtl_in_asm
#endif
#ifdef GENERATOR_FILE
extern int flag_evaluation_order;
#else
  int x_flag_evaluation_order;
#define flag_evaluation_order global_options.x_flag_evaluation_order
#endif
#ifdef GENERATOR_FILE
extern int flag_gen_aux_info;
#else
  int x_flag_gen_aux_info;
#define flag_gen_aux_info global_options.x_flag_gen_aux_info
#endif
#ifdef GENERATOR_FILE
extern int flag_generate_lto;
#else
  int x_flag_generate_lto;
#define flag_generate_lto global_options.x_flag_generate_lto
#endif
#ifdef GENERATOR_FILE
extern int flag_print_asm_name;
#else
  int x_flag_print_asm_name;
#define flag_print_asm_name global_options.x_flag_print_asm_name
#endif
#ifdef GENERATOR_FILE
extern int flag_shlib;
#else
  int x_flag_shlib;
#define flag_shlib global_options.x_flag_shlib
#endif
#ifdef GENERATOR_FILE
extern int main_input_baselength;
#else
  int x_main_input_baselength;
#define main_input_baselength global_options.x_main_input_baselength
#endif
#ifdef GENERATOR_FILE
extern int optimize;
#else
  int x_optimize;
#define optimize global_options.x_optimize
#endif
#ifdef GENERATOR_FILE
extern int optimize_fast;
#else
  int x_optimize_fast;
#define optimize_fast global_options.x_optimize_fast
#endif
#ifdef GENERATOR_FILE
extern int optimize_size;
#else
  int x_optimize_size;
#define optimize_size global_options.x_optimize_size
#endif
#ifdef GENERATOR_FILE
extern int rtl_dump_and_exit;
#else
  int x_rtl_dump_and_exit;
#define rtl_dump_and_exit global_options.x_rtl_dump_and_exit
#endif
#ifdef GENERATOR_FILE
extern int target_flags;
#else
  int x_target_flags;
#define target_flags global_options.x_target_flags
#endif
#ifdef GENERATOR_FILE
extern unsigned int help_columns;
#else
  unsigned int x_help_columns;
#define help_columns global_options.x_help_columns
#endif
#ifdef GENERATOR_FILE
extern unsigned int initial_max_fld_align;
#else
  unsigned int x_initial_max_fld_align;
#define initial_max_fld_align global_options.x_initial_max_fld_align
#endif
#ifdef GENERATOR_FILE
extern void *flag_instrument_functions_exclude_files;
#else
  void * x_flag_instrument_functions_exclude_files;
#define flag_instrument_functions_exclude_files global_options.x_flag_instrument_functions_exclude_files
#endif
#ifdef GENERATOR_FILE
extern void *flag_instrument_functions_exclude_functions;
#else
  void * x_flag_instrument_functions_exclude_functions;
#define flag_instrument_functions_exclude_functions global_options.x_flag_instrument_functions_exclude_functions
#endif
#ifdef GENERATOR_FILE
extern int help_flag;
#else
  int x_help_flag;
#define help_flag global_options.x_help_flag
#endif
#ifdef GENERATOR_FILE
extern int flag_preprocess_only;
#else
  int x_flag_preprocess_only;
#define flag_preprocess_only global_options.x_flag_preprocess_only
#endif
#ifdef GENERATOR_FILE
extern int g_switch_value;
#else
  int x_g_switch_value;
#define g_switch_value global_options.x_g_switch_value
#endif
#ifdef GENERATOR_FILE
extern int warn_abi;
#else
  int x_warn_abi;
#define warn_abi global_options.x_warn_abi
#endif
#ifdef GENERATOR_FILE
extern int warn_address;
#else
  int x_warn_address;
#define warn_address global_options.x_warn_address
#endif
#ifdef GENERATOR_FILE
extern int warn_aggregate_return;
#else
  int x_warn_aggregate_return;
#define warn_aggregate_return global_options.x_warn_aggregate_return
#endif
#ifdef GENERATOR_FILE
extern int warn_array_bounds;
#else
  int x_warn_array_bounds;
#define warn_array_bounds global_options.x_warn_array_bounds
#endif
#ifdef GENERATOR_FILE
extern int warn_assign_intercept;
#else
  int x_warn_assign_intercept;
#define warn_assign_intercept global_options.x_warn_assign_intercept
#endif
#ifdef GENERATOR_FILE
extern int warn_attributes;
#else
  int x_warn_attributes;
#define warn_attributes global_options.x_warn_attributes
#endif
#ifdef GENERATOR_FILE
extern int warn_bad_function_cast;
#else
  int x_warn_bad_function_cast;
#define warn_bad_function_cast global_options.x_warn_bad_function_cast
#endif
#ifdef GENERATOR_FILE
extern int warn_cxx_compat;
#else
  int x_warn_cxx_compat;
#define warn_cxx_compat global_options.x_warn_cxx_compat
#endif
#ifdef GENERATOR_FILE
extern int warn_cxx0x_compat;
#else
  int x_warn_cxx0x_compat;
#define warn_cxx0x_compat global_options.x_warn_cxx0x_compat
#endif
#ifdef GENERATOR_FILE
extern int warn_cast_align;
#else
  int x_warn_cast_align;
#define warn_cast_align global_options.x_warn_cast_align
#endif
#ifdef GENERATOR_FILE
extern int warn_cast_qual;
#else
  int x_warn_cast_qual;
#define warn_cast_qual global_options.x_warn_cast_qual
#endif
#ifdef GENERATOR_FILE
extern int warn_char_subscripts;
#else
  int x_warn_char_subscripts;
#define warn_char_subscripts global_options.x_warn_char_subscripts
#endif
#ifdef GENERATOR_FILE
extern int warn_clobbered;
#else
  int x_warn_clobbered;
#define warn_clobbered global_options.x_warn_clobbered
#endif
#ifdef GENERATOR_FILE
extern int warn_conversion;
#else
  int x_warn_conversion;
#define warn_conversion global_options.x_warn_conversion
#endif
#ifdef GENERATOR_FILE
extern int warn_conversion_null;
#else
  int x_warn_conversion_null;
#define warn_conversion_null global_options.x_warn_conversion_null
#endif
#ifdef GENERATOR_FILE
extern int warn_coverage_mismatch;
#else
  int x_warn_coverage_mismatch;
#define warn_coverage_mismatch global_options.x_warn_coverage_mismatch
#endif
#ifdef GENERATOR_FILE
extern int warn_cpp;
#else
  int x_warn_cpp;
#define warn_cpp global_options.x_warn_cpp
#endif
#ifdef GENERATOR_FILE
extern int warn_ctor_dtor_privacy;
#else
  int x_warn_ctor_dtor_privacy;
#define warn_ctor_dtor_privacy global_options.x_warn_ctor_dtor_privacy
#endif
#ifdef GENERATOR_FILE
extern int warn_declaration_after_statement;
#else
  int x_warn_declaration_after_statement;
#define warn_declaration_after_statement global_options.x_warn_declaration_after_statement
#endif
#ifdef GENERATOR_FILE
extern int warn_deprecated;
#else
  int x_warn_deprecated;
#define warn_deprecated global_options.x_warn_deprecated
#endif
#ifdef GENERATOR_FILE
extern int warn_deprecated_decl;
#else
  int x_warn_deprecated_decl;
#define warn_deprecated_decl global_options.x_warn_deprecated_decl
#endif
#ifdef GENERATOR_FILE
extern int warn_disabled_optimization;
#else
  int x_warn_disabled_optimization;
#define warn_disabled_optimization global_options.x_warn_disabled_optimization
#endif
#ifdef GENERATOR_FILE
extern int warn_div_by_zero;
#else
  int x_warn_div_by_zero;
#define warn_div_by_zero global_options.x_warn_div_by_zero
#endif
#ifdef GENERATOR_FILE
extern int warn_double_promotion;
#else
  int x_warn_double_promotion;
#define warn_double_promotion global_options.x_warn_double_promotion
#endif
#ifdef GENERATOR_FILE
extern int warn_ecpp;
#else
  int x_warn_ecpp;
#define warn_ecpp global_options.x_warn_ecpp
#endif
#ifdef GENERATOR_FILE
extern int warn_empty_body;
#else
  int x_warn_empty_body;
#define warn_empty_body global_options.x_warn_empty_body
#endif
#ifdef GENERATOR_FILE
extern int warn_enum_compare;
#else
  int x_warn_enum_compare;
#define warn_enum_compare global_options.x_warn_enum_compare
#endif
#ifdef GENERATOR_FILE
extern int warnings_are_errors;
#else
  int x_warnings_are_errors;
#define warnings_are_errors global_options.x_warnings_are_errors
#endif
#ifdef GENERATOR_FILE
extern int extra_warnings;
#else
  int x_extra_warnings;
#define extra_warnings global_options.x_extra_warnings
#endif
#ifdef GENERATOR_FILE
extern int flag_extraneous_semicolon;
#else
  int x_flag_extraneous_semicolon;
#define flag_extraneous_semicolon global_options.x_flag_extraneous_semicolon
#endif
#ifdef GENERATOR_FILE
extern int flag_fatal_errors;
#else
  int x_flag_fatal_errors;
#define flag_fatal_errors global_options.x_flag_fatal_errors
#endif
#ifdef GENERATOR_FILE
extern int warn_float_equal;
#else
  int x_warn_float_equal;
#define warn_float_equal global_options.x_warn_float_equal
#endif
#ifdef GENERATOR_FILE
extern int warn_format_contains_nul;
#else
  int x_warn_format_contains_nul;
#define warn_format_contains_nul global_options.x_warn_format_contains_nul
#endif
#ifdef GENERATOR_FILE
extern int warn_format_extra_args;
#else
  int x_warn_format_extra_args;
#define warn_format_extra_args global_options.x_warn_format_extra_args
#endif
#ifdef GENERATOR_FILE
extern int warn_format_nonliteral;
#else
  int x_warn_format_nonliteral;
#define warn_format_nonliteral global_options.x_warn_format_nonliteral
#endif
#ifdef GENERATOR_FILE
extern int warn_format_security;
#else
  int x_warn_format_security;
#define warn_format_security global_options.x_warn_format_security
#endif
#ifdef GENERATOR_FILE
extern int warn_format_y2k;
#else
  int x_warn_format_y2k;
#define warn_format_y2k global_options.x_warn_format_y2k
#endif
#ifdef GENERATOR_FILE
extern int warn_format_zero_length;
#else
  int x_warn_format_zero_length;
#define warn_format_zero_length global_options.x_warn_format_zero_length
#endif
#ifdef GENERATOR_FILE
extern int warn_ignored_qualifiers;
#else
  int x_warn_ignored_qualifiers;
#define warn_ignored_qualifiers global_options.x_warn_ignored_qualifiers
#endif
#ifdef GENERATOR_FILE
extern int warn_implicit;
#else
  int x_warn_implicit;
#define warn_implicit global_options.x_warn_implicit
#endif
#ifdef GENERATOR_FILE
extern int warn_implicit_function_declaration;
#else
  int x_warn_implicit_function_declaration;
#define warn_implicit_function_declaration global_options.x_warn_implicit_function_declaration
#endif
#ifdef GENERATOR_FILE
extern int warn_implicit_int;
#else
  int x_warn_implicit_int;
#define warn_implicit_int global_options.x_warn_implicit_int
#endif
#ifdef GENERATOR_FILE
extern int warn_init_self;
#else
  int x_warn_init_self;
#define warn_init_self global_options.x_warn_init_self
#endif
#ifdef GENERATOR_FILE
extern int warn_inline;
#else
  int x_warn_inline;
#define warn_inline global_options.x_warn_inline
#endif
#ifdef GENERATOR_FILE
extern int warn_int_to_pointer_cast;
#else
  int x_warn_int_to_pointer_cast;
#define warn_int_to_pointer_cast global_options.x_warn_int_to_pointer_cast
#endif
#ifdef GENERATOR_FILE
extern int warn_invalid_offsetof;
#else
  int x_warn_invalid_offsetof;
#define warn_invalid_offsetof global_options.x_warn_invalid_offsetof
#endif
#ifdef GENERATOR_FILE
extern int warn_jump_misses_init;
#else
  int x_warn_jump_misses_init;
#define warn_jump_misses_init global_options.x_warn_jump_misses_init
#endif
#ifdef GENERATOR_FILE
extern int warn_logical_op;
#else
  int x_warn_logical_op;
#define warn_logical_op global_options.x_warn_logical_op
#endif
#ifdef GENERATOR_FILE
extern int warn_long_long;
#else
  int x_warn_long_long;
#define warn_long_long global_options.x_warn_long_long
#endif
#ifdef GENERATOR_FILE
extern int warn_main;
#else
  int x_warn_main;
#define warn_main global_options.x_warn_main
#endif
#ifdef GENERATOR_FILE
extern int warn_missing_braces;
#else
  int x_warn_missing_braces;
#define warn_missing_braces global_options.x_warn_missing_braces
#endif
#ifdef GENERATOR_FILE
extern int warn_missing_declarations;
#else
  int x_warn_missing_declarations;
#define warn_missing_declarations global_options.x_warn_missing_declarations
#endif
#ifdef GENERATOR_FILE
extern int warn_missing_field_initializers;
#else
  int x_warn_missing_field_initializers;
#define warn_missing_field_initializers global_options.x_warn_missing_field_initializers
#endif
#ifdef GENERATOR_FILE
extern int warn_missing_format_attribute;
#else
  int x_warn_missing_format_attribute;
#define warn_missing_format_attribute global_options.x_warn_missing_format_attribute
#endif
#ifdef GENERATOR_FILE
extern int warn_missing_noreturn;
#else
  int x_warn_missing_noreturn;
#define warn_missing_noreturn global_options.x_warn_missing_noreturn
#endif
#ifdef GENERATOR_FILE
extern int warn_missing_parameter_type;
#else
  int x_warn_missing_parameter_type;
#define warn_missing_parameter_type global_options.x_warn_missing_parameter_type
#endif
#ifdef GENERATOR_FILE
extern int warn_missing_prototypes;
#else
  int x_warn_missing_prototypes;
#define warn_missing_prototypes global_options.x_warn_missing_prototypes
#endif
#ifdef GENERATOR_FILE
extern int warn_mudflap;
#else
  int x_warn_mudflap;
#define warn_mudflap global_options.x_warn_mudflap
#endif
#ifdef GENERATOR_FILE
extern int warn_nested_externs;
#else
  int x_warn_nested_externs;
#define warn_nested_externs global_options.x_warn_nested_externs
#endif
#ifdef GENERATOR_FILE
extern int warn_noexcept;
#else
  int x_warn_noexcept;
#define warn_noexcept global_options.x_warn_noexcept
#endif
#ifdef GENERATOR_FILE
extern int warn_nontemplate_friend;
#else
  int x_warn_nontemplate_friend;
#define warn_nontemplate_friend global_options.x_warn_nontemplate_friend
#endif
#ifdef GENERATOR_FILE
extern int warn_nonvdtor;
#else
  int x_warn_nonvdtor;
#define warn_nonvdtor global_options.x_warn_nonvdtor
#endif
#ifdef GENERATOR_FILE
extern int warn_nonnull;
#else
  int x_warn_nonnull;
#define warn_nonnull global_options.x_warn_nonnull
#endif
#ifdef GENERATOR_FILE
extern int warn_old_style_cast;
#else
  int x_warn_old_style_cast;
#define warn_old_style_cast global_options.x_warn_old_style_cast
#endif
#ifdef GENERATOR_FILE
extern int warn_old_style_declaration;
#else
  int x_warn_old_style_declaration;
#define warn_old_style_declaration global_options.x_warn_old_style_declaration
#endif
#ifdef GENERATOR_FILE
extern int warn_old_style_definition;
#else
  int x_warn_old_style_definition;
#define warn_old_style_definition global_options.x_warn_old_style_definition
#endif
#ifdef GENERATOR_FILE
extern int flag_newer;
#else
  int x_flag_newer;
#define flag_newer global_options.x_flag_newer
#endif
#ifdef GENERATOR_FILE
extern int warn_overflow;
#else
  int x_warn_overflow;
#define warn_overflow global_options.x_warn_overflow
#endif
#ifdef GENERATOR_FILE
extern int warn_overlength_strings;
#else
  int x_warn_overlength_strings;
#define warn_overlength_strings global_options.x_warn_overlength_strings
#endif
#ifdef GENERATOR_FILE
extern int warn_overloaded_virtual;
#else
  int x_warn_overloaded_virtual;
#define warn_overloaded_virtual global_options.x_warn_overloaded_virtual
#endif
#ifdef GENERATOR_FILE
extern int warn_override_init;
#else
  int x_warn_override_init;
#define warn_override_init global_options.x_warn_override_init
#endif
#ifdef GENERATOR_FILE
extern int warn_packed;
#else
  int x_warn_packed;
#define warn_packed global_options.x_warn_packed
#endif
#ifdef GENERATOR_FILE
extern int warn_packed_bitfield_compat;
#else
  int x_warn_packed_bitfield_compat;
#define warn_packed_bitfield_compat global_options.x_warn_packed_bitfield_compat
#endif
#ifdef GENERATOR_FILE
extern int warn_padded;
#else
  int x_warn_padded;
#define warn_padded global_options.x_warn_padded
#endif
#ifdef GENERATOR_FILE
extern int warn_parentheses;
#else
  int x_warn_parentheses;
#define warn_parentheses global_options.x_warn_parentheses
#endif
#ifdef GENERATOR_FILE
extern int warn_pmf2ptr;
#else
  int x_warn_pmf2ptr;
#define warn_pmf2ptr global_options.x_warn_pmf2ptr
#endif
#ifdef GENERATOR_FILE
extern int warn_pointer_arith;
#else
  int x_warn_pointer_arith;
#define warn_pointer_arith global_options.x_warn_pointer_arith
#endif
#ifdef GENERATOR_FILE
extern int warn_pointer_sign;
#else
  int x_warn_pointer_sign;
#define warn_pointer_sign global_options.x_warn_pointer_sign
#endif
#ifdef GENERATOR_FILE
extern int warn_pointer_to_int_cast;
#else
  int x_warn_pointer_to_int_cast;
#define warn_pointer_to_int_cast global_options.x_warn_pointer_to_int_cast
#endif
#ifdef GENERATOR_FILE
extern int warn_pragmas;
#else
  int x_warn_pragmas;
#define warn_pragmas global_options.x_warn_pragmas
#endif
#ifdef GENERATOR_FILE
extern int warn_property_assign_default;
#else
  int x_warn_property_assign_default;
#define warn_property_assign_default global_options.x_warn_property_assign_default
#endif
#ifdef GENERATOR_FILE
extern int warn_protocol;
#else
  int x_warn_protocol;
#define warn_protocol global_options.x_warn_protocol
#endif
#ifdef GENERATOR_FILE
extern int warn_psabi;
#else
  int x_warn_psabi;
#define warn_psabi global_options.x_warn_psabi
#endif
#ifdef GENERATOR_FILE
extern int warn_redundant_decls;
#else
  int x_warn_redundant_decls;
#define warn_redundant_decls global_options.x_warn_redundant_decls
#endif
#ifdef GENERATOR_FILE
extern int flag_redundant;
#else
  int x_flag_redundant;
#define flag_redundant global_options.x_flag_redundant
#endif
#ifdef GENERATOR_FILE
extern int warn_reorder;
#else
  int x_warn_reorder;
#define warn_reorder global_options.x_warn_reorder
#endif
#ifdef GENERATOR_FILE
extern int warn_return_type;
#else
  int x_warn_return_type;
#define warn_return_type global_options.x_warn_return_type
#endif
#ifdef GENERATOR_FILE
extern int warn_selector;
#else
  int x_warn_selector;
#define warn_selector global_options.x_warn_selector
#endif
#ifdef GENERATOR_FILE
extern int warn_sequence_point;
#else
  int x_warn_sequence_point;
#define warn_sequence_point global_options.x_warn_sequence_point
#endif
#ifdef GENERATOR_FILE
extern int warn_shadow;
#else
  int x_warn_shadow;
#define warn_shadow global_options.x_warn_shadow
#endif
#ifdef GENERATOR_FILE
extern int warn_sign_compare;
#else
  int x_warn_sign_compare;
#define warn_sign_compare global_options.x_warn_sign_compare
#endif
#ifdef GENERATOR_FILE
extern int warn_sign_conversion;
#else
  int x_warn_sign_conversion;
#define warn_sign_conversion global_options.x_warn_sign_conversion
#endif
#ifdef GENERATOR_FILE
extern int warn_sign_promo;
#else
  int x_warn_sign_promo;
#define warn_sign_promo global_options.x_warn_sign_promo
#endif
#ifdef GENERATOR_FILE
extern int warn_stack_protect;
#else
  int x_warn_stack_protect;
#define warn_stack_protect global_options.x_warn_stack_protect
#endif
#ifdef GENERATOR_FILE
extern int warn_strict_aliasing;
#else
  int x_warn_strict_aliasing;
#define warn_strict_aliasing global_options.x_warn_strict_aliasing
#endif
#ifdef GENERATOR_FILE
extern int warn_strict_null_sentinel;
#else
  int x_warn_strict_null_sentinel;
#define warn_strict_null_sentinel global_options.x_warn_strict_null_sentinel
#endif
#ifdef GENERATOR_FILE
extern int warn_strict_overflow;
#else
  int x_warn_strict_overflow;
#define warn_strict_overflow global_options.x_warn_strict_overflow
#endif
#ifdef GENERATOR_FILE
extern int warn_strict_prototypes;
#else
  int x_warn_strict_prototypes;
#define warn_strict_prototypes global_options.x_warn_strict_prototypes
#endif
#ifdef GENERATOR_FILE
extern int warn_strict_selector_match;
#else
  int x_warn_strict_selector_match;
#define warn_strict_selector_match global_options.x_warn_strict_selector_match
#endif
#ifdef GENERATOR_FILE
extern int warn_suggest_attribute_const;
#else
  int x_warn_suggest_attribute_const;
#define warn_suggest_attribute_const global_options.x_warn_suggest_attribute_const
#endif
#ifdef GENERATOR_FILE
extern int warn_suggest_attribute_noreturn;
#else
  int x_warn_suggest_attribute_noreturn;
#define warn_suggest_attribute_noreturn global_options.x_warn_suggest_attribute_noreturn
#endif
#ifdef GENERATOR_FILE
extern int warn_suggest_attribute_pure;
#else
  int x_warn_suggest_attribute_pure;
#define warn_suggest_attribute_pure global_options.x_warn_suggest_attribute_pure
#endif
#ifdef GENERATOR_FILE
extern int warn_switch;
#else
  int x_warn_switch;
#define warn_switch global_options.x_warn_switch
#endif
#ifdef GENERATOR_FILE
extern int warn_switch_default;
#else
  int x_warn_switch_default;
#define warn_switch_default global_options.x_warn_switch_default
#endif
#ifdef GENERATOR_FILE
extern int warn_switch_enum;
#else
  int x_warn_switch_enum;
#define warn_switch_enum global_options.x_warn_switch_enum
#endif
#ifdef GENERATOR_FILE
extern int warn_sync_nand;
#else
  int x_warn_sync_nand;
#define warn_sync_nand global_options.x_warn_sync_nand
#endif
#ifdef GENERATOR_FILE
extern int warn_synth;
#else
  int x_warn_synth;
#define warn_synth global_options.x_warn_synth
#endif
#ifdef GENERATOR_FILE
extern int warn_system_headers;
#else
  int x_warn_system_headers;
#define warn_system_headers global_options.x_warn_system_headers
#endif
#ifdef GENERATOR_FILE
extern int warn_traditional;
#else
  int x_warn_traditional;
#define warn_traditional global_options.x_warn_traditional
#endif
#ifdef GENERATOR_FILE
extern int warn_traditional_conversion;
#else
  int x_warn_traditional_conversion;
#define warn_traditional_conversion global_options.x_warn_traditional_conversion
#endif
#ifdef GENERATOR_FILE
extern int warn_trampolines;
#else
  int x_warn_trampolines;
#define warn_trampolines global_options.x_warn_trampolines
#endif
#ifdef GENERATOR_FILE
extern int warn_type_limits;
#else
  int x_warn_type_limits;
#define warn_type_limits global_options.x_warn_type_limits
#endif
#ifdef GENERATOR_FILE
extern int warn_undeclared_selector;
#else
  int x_warn_undeclared_selector;
#define warn_undeclared_selector global_options.x_warn_undeclared_selector
#endif
#ifdef GENERATOR_FILE
extern int warn_uninitialized;
#else
  int x_warn_uninitialized;
#define warn_uninitialized global_options.x_warn_uninitialized
#endif
#ifdef GENERATOR_FILE
extern int warn_unsafe_loop_optimizations;
#else
  int x_warn_unsafe_loop_optimizations;
#define warn_unsafe_loop_optimizations global_options.x_warn_unsafe_loop_optimizations
#endif
#ifdef GENERATOR_FILE
extern int warn_unsuffixed_float_constants;
#else
  int x_warn_unsuffixed_float_constants;
#define warn_unsuffixed_float_constants global_options.x_warn_unsuffixed_float_constants
#endif
#ifdef GENERATOR_FILE
extern int warn_unused;
#else
  int x_warn_unused;
#define warn_unused global_options.x_warn_unused
#endif
#ifdef GENERATOR_FILE
extern int warn_unused_but_set_parameter;
#else
  int x_warn_unused_but_set_parameter;
#define warn_unused_but_set_parameter global_options.x_warn_unused_but_set_parameter
#endif
#ifdef GENERATOR_FILE
extern int warn_unused_but_set_variable;
#else
  int x_warn_unused_but_set_variable;
#define warn_unused_but_set_variable global_options.x_warn_unused_but_set_variable
#endif
#ifdef GENERATOR_FILE
extern int warn_unused_function;
#else
  int x_warn_unused_function;
#define warn_unused_function global_options.x_warn_unused_function
#endif
#ifdef GENERATOR_FILE
extern int warn_unused_label;
#else
  int x_warn_unused_label;
#define warn_unused_label global_options.x_warn_unused_label
#endif
#ifdef GENERATOR_FILE
extern int warn_unused_parameter;
#else
  int x_warn_unused_parameter;
#define warn_unused_parameter global_options.x_warn_unused_parameter
#endif
#ifdef GENERATOR_FILE
extern int warn_unused_result;
#else
  int x_warn_unused_result;
#define warn_unused_result global_options.x_warn_unused_result
#endif
#ifdef GENERATOR_FILE
extern int warn_unused_value;
#else
  int x_warn_unused_value;
#define warn_unused_value global_options.x_warn_unused_value
#endif
#ifdef GENERATOR_FILE
extern int warn_unused_variable;
#else
  int x_warn_unused_variable;
#define warn_unused_variable global_options.x_warn_unused_variable
#endif
#ifdef GENERATOR_FILE
extern int warn_vla;
#else
  int x_warn_vla;
#define warn_vla global_options.x_warn_vla
#endif
#ifdef GENERATOR_FILE
extern int warn_volatile_register_var;
#else
  int x_warn_volatile_register_var;
#define warn_volatile_register_var global_options.x_warn_volatile_register_var
#endif
#ifdef GENERATOR_FILE
extern int warn_write_strings;
#else
  int x_warn_write_strings;
#define warn_write_strings global_options.x_warn_write_strings
#endif
#ifdef GENERATOR_FILE
extern const char *aux_info_file_name;
#else
  const char *x_aux_info_file_name;
#define aux_info_file_name global_options.x_aux_info_file_name
#endif
#ifdef GENERATOR_FILE
extern const char *aux_base_name;
#else
  const char *x_aux_base_name;
#define aux_base_name global_options.x_aux_base_name
#endif
#ifdef GENERATOR_FILE
extern const char *dump_base_name;
#else
  const char *x_dump_base_name;
#define dump_base_name global_options.x_dump_base_name
#endif
#ifdef GENERATOR_FILE
extern const char *dump_dir_name;
#else
  const char *x_dump_dir_name;
#define dump_dir_name global_options.x_dump_dir_name
#endif
#ifdef GENERATOR_FILE
extern int flag_pic;
#else
  int x_flag_pic;
#define flag_pic global_options.x_flag_pic
#endif
#ifdef GENERATOR_FILE
extern int flag_pie;
#else
  int x_flag_pie;
#define flag_pie global_options.x_flag_pie
#endif
#ifdef GENERATOR_FILE
extern int flag_abi_version;
#else
  int x_flag_abi_version;
#define flag_abi_version global_options.x_flag_abi_version
#endif
#ifdef GENERATOR_FILE
extern int flag_access_control;
#else
  int x_flag_access_control;
#define flag_access_control global_options.x_flag_access_control
#endif
#ifdef GENERATOR_FILE
extern int align_functions;
#else
  int x_align_functions;
#define align_functions global_options.x_align_functions
#endif
#ifdef GENERATOR_FILE
extern int align_jumps;
#else
  int x_align_jumps;
#define align_jumps global_options.x_align_jumps
#endif
#ifdef GENERATOR_FILE
extern int align_labels;
#else
  int x_align_labels;
#define align_labels global_options.x_align_labels
#endif
#ifdef GENERATOR_FILE
extern int align_loops;
#else
  int x_align_loops;
#define align_loops global_options.x_align_loops
#endif
#ifdef GENERATOR_FILE
extern int flag_no_asm;
#else
  int x_flag_no_asm;
#define flag_no_asm global_options.x_flag_no_asm
#endif
#ifdef GENERATOR_FILE
extern int flag_assert;
#else
  int x_flag_assert;
#define flag_assert global_options.x_flag_assert
#endif
#ifdef GENERATOR_FILE
extern int flag_associative_math;
#else
  int x_flag_associative_math;
#define flag_associative_math global_options.x_flag_associative_math
#endif
#ifdef GENERATOR_FILE
extern int flag_asynchronous_unwind_tables;
#else
  int x_flag_asynchronous_unwind_tables;
#define flag_asynchronous_unwind_tables global_options.x_flag_asynchronous_unwind_tables
#endif
#ifdef GENERATOR_FILE
extern int flag_auto_inc_dec;
#else
  int x_flag_auto_inc_dec;
#define flag_auto_inc_dec global_options.x_flag_auto_inc_dec
#endif
#ifdef GENERATOR_FILE
extern int flag_bootstrap_classes;
#else
  int x_flag_bootstrap_classes;
#define flag_bootstrap_classes global_options.x_flag_bootstrap_classes
#endif
#ifdef GENERATOR_FILE
extern int flag_bounds_check;
#else
  int x_flag_bounds_check;
#define flag_bounds_check global_options.x_flag_bounds_check
#endif
#ifdef GENERATOR_FILE
extern int flag_branch_on_count_reg;
#else
  int x_flag_branch_on_count_reg;
#define flag_branch_on_count_reg global_options.x_flag_branch_on_count_reg
#endif
#ifdef GENERATOR_FILE
extern int flag_branch_probabilities;
#else
  int x_flag_branch_probabilities;
#define flag_branch_probabilities global_options.x_flag_branch_probabilities
#endif
#ifdef GENERATOR_FILE
extern int flag_branch_target_load_optimize;
#else
  int x_flag_branch_target_load_optimize;
#define flag_branch_target_load_optimize global_options.x_flag_branch_target_load_optimize
#endif
#ifdef GENERATOR_FILE
extern int flag_branch_target_load_optimize2;
#else
  int x_flag_branch_target_load_optimize2;
#define flag_branch_target_load_optimize2 global_options.x_flag_branch_target_load_optimize2
#endif
#ifdef GENERATOR_FILE
extern int flag_btr_bb_exclusive;
#else
  int x_flag_btr_bb_exclusive;
#define flag_btr_bb_exclusive global_options.x_flag_btr_bb_exclusive
#endif
#ifdef GENERATOR_FILE
extern int flag_no_builtin;
#else
  int x_flag_no_builtin;
#define flag_no_builtin global_options.x_flag_no_builtin
#endif
#ifdef GENERATOR_FILE
extern void *common_deferred_options;
#else
  void *x_common_deferred_options;
#define common_deferred_options global_options.x_common_deferred_options
#endif
#ifdef GENERATOR_FILE
extern int flag_caller_saves;
#else
  int x_flag_caller_saves;
#define flag_caller_saves global_options.x_flag_caller_saves
#endif
#ifdef GENERATOR_FILE
extern int flag_check_data_deps;
#else
  int x_flag_check_data_deps;
#define flag_check_data_deps global_options.x_flag_check_data_deps
#endif
#ifdef GENERATOR_FILE
extern int flag_check_new;
#else
  int x_flag_check_new;
#define flag_check_new global_options.x_flag_check_new
#endif
#ifdef GENERATOR_FILE
extern int flag_check_references;
#else
  int x_flag_check_references;
#define flag_check_references global_options.x_flag_check_references
#endif
#ifdef GENERATOR_FILE
extern int flag_combine_stack_adjustments;
#else
  int x_flag_combine_stack_adjustments;
#define flag_combine_stack_adjustments global_options.x_flag_combine_stack_adjustments
#endif
#ifdef GENERATOR_FILE
extern int flag_no_common;
#else
  int x_flag_no_common;
#define flag_no_common global_options.x_flag_no_common
#endif
#ifdef GENERATOR_FILE
extern int flag_compare_debug;
#else
  int x_flag_compare_debug;
#define flag_compare_debug global_options.x_flag_compare_debug
#endif
#ifdef GENERATOR_FILE
extern const char *flag_compare_debug_opt;
#else
  const char *x_flag_compare_debug_opt;
#define flag_compare_debug_opt global_options.x_flag_compare_debug_opt
#endif
#ifdef GENERATOR_FILE
extern int flag_compare_elim_after_reload;
#else
  int x_flag_compare_elim_after_reload;
#define flag_compare_elim_after_reload global_options.x_flag_compare_elim_after_reload
#endif
#ifdef GENERATOR_FILE
extern int flag_conserve_space;
#else
  int x_flag_conserve_space;
#define flag_conserve_space global_options.x_flag_conserve_space
#endif
#ifdef GENERATOR_FILE
extern int flag_conserve_stack;
#else
  int x_flag_conserve_stack;
#define flag_conserve_stack global_options.x_flag_conserve_stack
#endif
#ifdef GENERATOR_FILE
extern int max_constexpr_depth;
#else
  int x_max_constexpr_depth;
#define max_constexpr_depth global_options.x_max_constexpr_depth
#endif
#ifdef GENERATOR_FILE
extern int flag_cprop_registers;
#else
  int x_flag_cprop_registers;
#define flag_cprop_registers global_options.x_flag_cprop_registers
#endif
#ifdef GENERATOR_FILE
extern int flag_crossjumping;
#else
  int x_flag_crossjumping;
#define flag_crossjumping global_options.x_flag_crossjumping
#endif
#ifdef GENERATOR_FILE
extern int flag_cse_follow_jumps;
#else
  int x_flag_cse_follow_jumps;
#define flag_cse_follow_jumps global_options.x_flag_cse_follow_jumps
#endif
#ifdef GENERATOR_FILE
extern int flag_cx_fortran_rules;
#else
  int x_flag_cx_fortran_rules;
#define flag_cx_fortran_rules global_options.x_flag_cx_fortran_rules
#endif
#ifdef GENERATOR_FILE
extern int flag_cx_limited_range;
#else
  int x_flag_cx_limited_range;
#define flag_cx_limited_range global_options.x_flag_cx_limited_range
#endif
#ifdef GENERATOR_FILE
extern int flag_data_sections;
#else
  int x_flag_data_sections;
#define flag_data_sections global_options.x_flag_data_sections
#endif
#ifdef GENERATOR_FILE
extern int flag_dce;
#else
  int x_flag_dce;
#define flag_dce global_options.x_flag_dce
#endif
#ifdef GENERATOR_FILE
extern int flag_deduce_init_list;
#else
  int x_flag_deduce_init_list;
#define flag_deduce_init_list global_options.x_flag_deduce_init_list
#endif
#ifdef GENERATOR_FILE
extern int flag_defer_pop;
#else
  int x_flag_defer_pop;
#define flag_defer_pop global_options.x_flag_defer_pop
#endif
#ifdef GENERATOR_FILE
extern int flag_delayed_branch;
#else
  int x_flag_delayed_branch;
#define flag_delayed_branch global_options.x_flag_delayed_branch
#endif
#ifdef GENERATOR_FILE
extern int flag_delete_null_pointer_checks;
#else
  int x_flag_delete_null_pointer_checks;
#define flag_delete_null_pointer_checks global_options.x_flag_delete_null_pointer_checks
#endif
#ifdef GENERATOR_FILE
extern int flag_devirtualize;
#else
  int x_flag_devirtualize;
#define flag_devirtualize global_options.x_flag_devirtualize
#endif
#ifdef GENERATOR_FILE
extern int flag_diagnostics_show_option;
#else
  int x_flag_diagnostics_show_option;
#define flag_diagnostics_show_option global_options.x_flag_diagnostics_show_option
#endif
#ifdef GENERATOR_FILE
extern int flag_dse;
#else
  int x_flag_dse;
#define flag_dse global_options.x_flag_dse
#endif
#ifdef GENERATOR_FILE
extern const char *flag_dump_final_insns;
#else
  const char *x_flag_dump_final_insns;
#define flag_dump_final_insns global_options.x_flag_dump_final_insns
#endif
#ifdef GENERATOR_FILE
extern const char *flag_dump_go_spec;
#else
  const char *x_flag_dump_go_spec;
#define flag_dump_go_spec global_options.x_flag_dump_go_spec
#endif
#ifdef GENERATOR_FILE
extern int flag_dump_noaddr;
#else
  int x_flag_dump_noaddr;
#define flag_dump_noaddr global_options.x_flag_dump_noaddr
#endif
#ifdef GENERATOR_FILE
extern int flag_dump_unnumbered;
#else
  int x_flag_dump_unnumbered;
#define flag_dump_unnumbered global_options.x_flag_dump_unnumbered
#endif
#ifdef GENERATOR_FILE
extern int flag_dump_unnumbered_links;
#else
  int x_flag_dump_unnumbered_links;
#define flag_dump_unnumbered_links global_options.x_flag_dump_unnumbered_links
#endif
#ifdef GENERATOR_FILE
extern int flag_dwarf2_cfi_asm;
#else
  int x_flag_dwarf2_cfi_asm;
#define flag_dwarf2_cfi_asm global_options.x_flag_dwarf2_cfi_asm
#endif
#ifdef GENERATOR_FILE
extern int flag_early_inlining;
#else
  int x_flag_early_inlining;
#define flag_early_inlining global_options.x_flag_early_inlining
#endif
#ifdef GENERATOR_FILE
extern int flag_elide_constructors;
#else
  int x_flag_elide_constructors;
#define flag_elide_constructors global_options.x_flag_elide_constructors
#endif
#ifdef GENERATOR_FILE
extern int flag_eliminate_dwarf2_dups;
#else
  int x_flag_eliminate_dwarf2_dups;
#define flag_eliminate_dwarf2_dups global_options.x_flag_eliminate_dwarf2_dups
#endif
#ifdef GENERATOR_FILE
extern int flag_debug_only_used_symbols;
#else
  int x_flag_debug_only_used_symbols;
#define flag_debug_only_used_symbols global_options.x_flag_debug_only_used_symbols
#endif
#ifdef GENERATOR_FILE
extern int flag_eliminate_unused_debug_types;
#else
  int x_flag_eliminate_unused_debug_types;
#define flag_eliminate_unused_debug_types global_options.x_flag_eliminate_unused_debug_types
#endif
#ifdef GENERATOR_FILE
extern int flag_emit_class_debug_always;
#else
  int x_flag_emit_class_debug_always;
#define flag_emit_class_debug_always global_options.x_flag_emit_class_debug_always
#endif
#ifdef GENERATOR_FILE
extern int flag_emit_class_files;
#else
  int x_flag_emit_class_files;
#define flag_emit_class_files global_options.x_flag_emit_class_files
#endif
#ifdef GENERATOR_FILE
extern int flag_enable_icf_debug;
#else
  int x_flag_enable_icf_debug;
#define flag_enable_icf_debug global_options.x_flag_enable_icf_debug
#endif
#ifdef GENERATOR_FILE
extern int flag_enforce_eh_specs;
#else
  int x_flag_enforce_eh_specs;
#define flag_enforce_eh_specs global_options.x_flag_enforce_eh_specs
#endif
#ifdef GENERATOR_FILE
extern int flag_exceptions;
#else
  int x_flag_exceptions;
#define flag_exceptions global_options.x_flag_exceptions
#endif
#ifdef GENERATOR_FILE
extern enum excess_precision flag_excess_precision_cmdline;
#else
  enum excess_precision x_flag_excess_precision_cmdline;
#define flag_excess_precision_cmdline global_options.x_flag_excess_precision_cmdline
#endif
#ifdef GENERATOR_FILE
extern int flag_expensive_optimizations;
#else
  int x_flag_expensive_optimizations;
#define flag_expensive_optimizations global_options.x_flag_expensive_optimizations
#endif
#ifdef GENERATOR_FILE
extern int flag_filelist_file;
#else
  int x_flag_filelist_file;
#define flag_filelist_file global_options.x_flag_filelist_file
#endif
#ifdef GENERATOR_FILE
extern int flag_finite_math_only;
#else
  int x_flag_finite_math_only;
#define flag_finite_math_only global_options.x_flag_finite_math_only
#endif
#ifdef GENERATOR_FILE
extern int flag_float_store;
#else
  int x_flag_float_store;
#define flag_float_store global_options.x_flag_float_store
#endif
#ifdef GENERATOR_FILE
extern int flag_new_for_scope;
#else
  int x_flag_new_for_scope;
#define flag_new_for_scope global_options.x_flag_new_for_scope
#endif
#ifdef GENERATOR_FILE
extern int flag_force_classes_archive_check;
#else
  int x_flag_force_classes_archive_check;
#define flag_force_classes_archive_check global_options.x_flag_force_classes_archive_check
#endif
#ifdef GENERATOR_FILE
extern int flag_forward_propagate;
#else
  int x_flag_forward_propagate;
#define flag_forward_propagate global_options.x_flag_forward_propagate
#endif
#ifdef GENERATOR_FILE
extern enum fp_contract_mode flag_fp_contract_mode;
#else
  enum fp_contract_mode x_flag_fp_contract_mode;
#define flag_fp_contract_mode global_options.x_flag_fp_contract_mode
#endif
#ifdef GENERATOR_FILE
extern int flag_friend_injection;
#else
  int x_flag_friend_injection;
#define flag_friend_injection global_options.x_flag_friend_injection
#endif
#ifdef GENERATOR_FILE
extern int flag_no_function_cse;
#else
  int x_flag_no_function_cse;
#define flag_no_function_cse global_options.x_flag_no_function_cse
#endif
#ifdef GENERATOR_FILE
extern int flag_function_sections;
#else
  int x_flag_function_sections;
#define flag_function_sections global_options.x_flag_function_sections
#endif
#ifdef GENERATOR_FILE
extern int flag_gcse;
#else
  int x_flag_gcse;
#define flag_gcse global_options.x_flag_gcse
#endif
#ifdef GENERATOR_FILE
extern int flag_gcse_after_reload;
#else
  int x_flag_gcse_after_reload;
#define flag_gcse_after_reload global_options.x_flag_gcse_after_reload
#endif
#ifdef GENERATOR_FILE
extern int flag_gcse_las;
#else
  int x_flag_gcse_las;
#define flag_gcse_las global_options.x_flag_gcse_las
#endif
#ifdef GENERATOR_FILE
extern int flag_gcse_lm;
#else
  int x_flag_gcse_lm;
#define flag_gcse_lm global_options.x_flag_gcse_lm
#endif
#ifdef GENERATOR_FILE
extern int flag_gcse_sm;
#else
  int x_flag_gcse_sm;
#define flag_gcse_sm global_options.x_flag_gcse_sm
#endif
#ifdef GENERATOR_FILE
extern int flag_no_gnu_keywords;
#else
  int x_flag_no_gnu_keywords;
#define flag_no_gnu_keywords global_options.x_flag_no_gnu_keywords
#endif
#ifdef GENERATOR_FILE
extern int flag_gnu89_inline;
#else
  int x_flag_gnu89_inline;
#define flag_gnu89_inline global_options.x_flag_gnu89_inline
#endif
#ifdef GENERATOR_FILE
extern int flag_graphite;
#else
  int x_flag_graphite;
#define flag_graphite global_options.x_flag_graphite
#endif
#ifdef GENERATOR_FILE
extern int flag_graphite_identity;
#else
  int x_flag_graphite_identity;
#define flag_graphite_identity global_options.x_flag_graphite_identity
#endif
#ifdef GENERATOR_FILE
extern int flag_guess_branch_prob;
#else
  int x_flag_guess_branch_prob;
#define flag_guess_branch_prob global_options.x_flag_guess_branch_prob
#endif
#ifdef GENERATOR_FILE
extern int flag_hash_synchronization;
#else
  int x_flag_hash_synchronization;
#define flag_hash_synchronization global_options.x_flag_hash_synchronization
#endif
#ifdef GENERATOR_FILE
extern int flag_no_ident;
#else
  int x_flag_no_ident;
#define flag_no_ident global_options.x_flag_no_ident
#endif
#ifdef GENERATOR_FILE
extern int flag_if_conversion;
#else
  int x_flag_if_conversion;
#define flag_if_conversion global_options.x_flag_if_conversion
#endif
#ifdef GENERATOR_FILE
extern int flag_if_conversion2;
#else
  int x_flag_if_conversion2;
#define flag_if_conversion2 global_options.x_flag_if_conversion2
#endif
#ifdef GENERATOR_FILE
extern int flag_implement_inlines;
#else
  int x_flag_implement_inlines;
#define flag_implement_inlines global_options.x_flag_implement_inlines
#endif
#ifdef GENERATOR_FILE
extern int flag_implicit_inline_templates;
#else
  int x_flag_implicit_inline_templates;
#define flag_implicit_inline_templates global_options.x_flag_implicit_inline_templates
#endif
#ifdef GENERATOR_FILE
extern int flag_implicit_templates;
#else
  int x_flag_implicit_templates;
#define flag_implicit_templates global_options.x_flag_implicit_templates
#endif
#ifdef GENERATOR_FILE
extern int flag_indirect_classes;
#else
  int x_flag_indirect_classes;
#define flag_indirect_classes global_options.x_flag_indirect_classes
#endif
#ifdef GENERATOR_FILE
extern int flag_indirect_dispatch;
#else
  int x_flag_indirect_dispatch;
#define flag_indirect_dispatch global_options.x_flag_indirect_dispatch
#endif
#ifdef GENERATOR_FILE
extern int flag_indirect_inlining;
#else
  int x_flag_indirect_inlining;
#define flag_indirect_inlining global_options.x_flag_indirect_inlining
#endif
#ifdef GENERATOR_FILE
extern int flag_inhibit_size_directive;
#else
  int x_flag_inhibit_size_directive;
#define flag_inhibit_size_directive global_options.x_flag_inhibit_size_directive
#endif
#ifdef GENERATOR_FILE
extern int flag_no_inline;
#else
  int x_flag_no_inline;
#define flag_no_inline global_options.x_flag_no_inline
#endif
#ifdef GENERATOR_FILE
extern int flag_inline_functions;
#else
  int x_flag_inline_functions;
#define flag_inline_functions global_options.x_flag_inline_functions
#endif
#ifdef GENERATOR_FILE
extern int flag_inline_functions_called_once;
#else
  int x_flag_inline_functions_called_once;
#define flag_inline_functions_called_once global_options.x_flag_inline_functions_called_once
#endif
#ifdef GENERATOR_FILE
extern int flag_inline_small_functions;
#else
  int x_flag_inline_small_functions;
#define flag_inline_small_functions global_options.x_flag_inline_small_functions
#endif
#ifdef GENERATOR_FILE
extern int flag_instrument_function_entry_exit;
#else
  int x_flag_instrument_function_entry_exit;
#define flag_instrument_function_entry_exit global_options.x_flag_instrument_function_entry_exit
#endif
#ifdef GENERATOR_FILE
extern int flag_ipa_cp;
#else
  int x_flag_ipa_cp;
#define flag_ipa_cp global_options.x_flag_ipa_cp
#endif
#ifdef GENERATOR_FILE
extern int flag_ipa_cp_clone;
#else
  int x_flag_ipa_cp_clone;
#define flag_ipa_cp_clone global_options.x_flag_ipa_cp_clone
#endif
#ifdef GENERATOR_FILE
extern int flag_ipa_matrix_reorg;
#else
  int x_flag_ipa_matrix_reorg;
#define flag_ipa_matrix_reorg global_options.x_flag_ipa_matrix_reorg
#endif
#ifdef GENERATOR_FILE
extern int flag_ipa_profile;
#else
  int x_flag_ipa_profile;
#define flag_ipa_profile global_options.x_flag_ipa_profile
#endif
#ifdef GENERATOR_FILE
extern int flag_ipa_pta;
#else
  int x_flag_ipa_pta;
#define flag_ipa_pta global_options.x_flag_ipa_pta
#endif
#ifdef GENERATOR_FILE
extern int flag_ipa_pure_const;
#else
  int x_flag_ipa_pure_const;
#define flag_ipa_pure_const global_options.x_flag_ipa_pure_const
#endif
#ifdef GENERATOR_FILE
extern int flag_ipa_reference;
#else
  int x_flag_ipa_reference;
#define flag_ipa_reference global_options.x_flag_ipa_reference
#endif
#ifdef GENERATOR_FILE
extern int flag_ipa_sra;
#else
  int x_flag_ipa_sra;
#define flag_ipa_sra global_options.x_flag_ipa_sra
#endif
#ifdef GENERATOR_FILE
extern int flag_ipa_struct_reorg;
#else
  int x_flag_ipa_struct_reorg;
#define flag_ipa_struct_reorg global_options.x_flag_ipa_struct_reorg
#endif
#ifdef GENERATOR_FILE
extern enum ira_algorithm flag_ira_algorithm;
#else
  enum ira_algorithm x_flag_ira_algorithm;
#define flag_ira_algorithm global_options.x_flag_ira_algorithm
#endif
#ifdef GENERATOR_FILE
extern int flag_ira_loop_pressure;
#else
  int x_flag_ira_loop_pressure;
#define flag_ira_loop_pressure global_options.x_flag_ira_loop_pressure
#endif
#ifdef GENERATOR_FILE
extern enum ira_region flag_ira_region;
#else
  enum ira_region x_flag_ira_region;
#define flag_ira_region global_options.x_flag_ira_region
#endif
#ifdef GENERATOR_FILE
extern int flag_ira_share_save_slots;
#else
  int x_flag_ira_share_save_slots;
#define flag_ira_share_save_slots global_options.x_flag_ira_share_save_slots
#endif
#ifdef GENERATOR_FILE
extern int flag_ira_share_spill_slots;
#else
  int x_flag_ira_share_spill_slots;
#define flag_ira_share_spill_slots global_options.x_flag_ira_share_spill_slots
#endif
#ifdef GENERATOR_FILE
extern int flag_ira_verbose;
#else
  int x_flag_ira_verbose;
#define flag_ira_verbose global_options.x_flag_ira_verbose
#endif
#ifdef GENERATOR_FILE
extern int flag_ivopts;
#else
  int x_flag_ivopts;
#define flag_ivopts global_options.x_flag_ivopts
#endif
#ifdef GENERATOR_FILE
extern int flag_jni;
#else
  int x_flag_jni;
#define flag_jni global_options.x_flag_jni
#endif
#ifdef GENERATOR_FILE
extern int flag_jump_tables;
#else
  int x_flag_jump_tables;
#define flag_jump_tables global_options.x_flag_jump_tables
#endif
#ifdef GENERATOR_FILE
extern int flag_keep_inline_dllexport;
#else
  int x_flag_keep_inline_dllexport;
#define flag_keep_inline_dllexport global_options.x_flag_keep_inline_dllexport
#endif
#ifdef GENERATOR_FILE
extern int flag_keep_inline_functions;
#else
  int x_flag_keep_inline_functions;
#define flag_keep_inline_functions global_options.x_flag_keep_inline_functions
#endif
#ifdef GENERATOR_FILE
extern int flag_keep_static_consts;
#else
  int x_flag_keep_static_consts;
#define flag_keep_static_consts global_options.x_flag_keep_static_consts
#endif
#ifdef GENERATOR_FILE
extern int flag_lax_vector_conversions;
#else
  int x_flag_lax_vector_conversions;
#define flag_lax_vector_conversions global_options.x_flag_lax_vector_conversions
#endif
#ifdef GENERATOR_FILE
extern int flag_leading_underscore;
#else
  int x_flag_leading_underscore;
#define flag_leading_underscore global_options.x_flag_leading_underscore
#endif
#ifdef GENERATOR_FILE
extern int flag_loop_block;
#else
  int x_flag_loop_block;
#define flag_loop_block global_options.x_flag_loop_block
#endif
#ifdef GENERATOR_FILE
extern int flag_loop_flatten;
#else
  int x_flag_loop_flatten;
#define flag_loop_flatten global_options.x_flag_loop_flatten
#endif
#ifdef GENERATOR_FILE
extern int flag_loop_interchange;
#else
  int x_flag_loop_interchange;
#define flag_loop_interchange global_options.x_flag_loop_interchange
#endif
#ifdef GENERATOR_FILE
extern int flag_loop_parallelize_all;
#else
  int x_flag_loop_parallelize_all;
#define flag_loop_parallelize_all global_options.x_flag_loop_parallelize_all
#endif
#ifdef GENERATOR_FILE
extern int flag_loop_strip_mine;
#else
  int x_flag_loop_strip_mine;
#define flag_loop_strip_mine global_options.x_flag_loop_strip_mine
#endif
#ifdef GENERATOR_FILE
extern int flag_lto_compression_level;
#else
  int x_flag_lto_compression_level;
#define flag_lto_compression_level global_options.x_flag_lto_compression_level
#endif
#ifdef GENERATOR_FILE
extern int flag_lto_partition_1to1;
#else
  int x_flag_lto_partition_1to1;
#define flag_lto_partition_1to1 global_options.x_flag_lto_partition_1to1
#endif
#ifdef GENERATOR_FILE
extern int flag_lto_partition_balanced;
#else
  int x_flag_lto_partition_balanced;
#define flag_lto_partition_balanced global_options.x_flag_lto_partition_balanced
#endif
#ifdef GENERATOR_FILE
extern int flag_lto_partition_none;
#else
  int x_flag_lto_partition_none;
#define flag_lto_partition_none global_options.x_flag_lto_partition_none
#endif
#ifdef GENERATOR_FILE
extern int flag_lto_report;
#else
  int x_flag_lto_report;
#define flag_lto_report global_options.x_flag_lto_report
#endif
#ifdef GENERATOR_FILE
extern const char *flag_lto;
#else
  const char *x_flag_lto;
#define flag_lto global_options.x_flag_lto
#endif
#ifdef GENERATOR_FILE
extern int flag_ltrans;
#else
  int x_flag_ltrans;
#define flag_ltrans global_options.x_flag_ltrans
#endif
#ifdef GENERATOR_FILE
extern const char *ltrans_output_list;
#else
  const char *x_ltrans_output_list;
#define ltrans_output_list global_options.x_ltrans_output_list
#endif
#ifdef GENERATOR_FILE
extern int flag_errno_math;
#else
  int x_flag_errno_math;
#define flag_errno_math global_options.x_flag_errno_math
#endif
#ifdef GENERATOR_FILE
extern int flag_max_errors;
#else
  int x_flag_max_errors;
#define flag_max_errors global_options.x_flag_max_errors
#endif
#ifdef GENERATOR_FILE
extern int mem_report;
#else
  int x_mem_report;
#define mem_report global_options.x_mem_report
#endif
#ifdef GENERATOR_FILE
extern int flag_merge_constants;
#else
  int x_flag_merge_constants;
#define flag_merge_constants global_options.x_flag_merge_constants
#endif
#ifdef GENERATOR_FILE
extern int flag_merge_debug_strings;
#else
  int x_flag_merge_debug_strings;
#define flag_merge_debug_strings global_options.x_flag_merge_debug_strings
#endif
#ifdef GENERATOR_FILE
extern int flag_modulo_sched;
#else
  int x_flag_modulo_sched;
#define flag_modulo_sched global_options.x_flag_modulo_sched
#endif
#ifdef GENERATOR_FILE
extern int flag_modulo_sched_allow_regmoves;
#else
  int x_flag_modulo_sched_allow_regmoves;
#define flag_modulo_sched_allow_regmoves global_options.x_flag_modulo_sched_allow_regmoves
#endif
#ifdef GENERATOR_FILE
extern int flag_move_loop_invariants;
#else
  int x_flag_move_loop_invariants;
#define flag_move_loop_invariants global_options.x_flag_move_loop_invariants
#endif
#ifdef GENERATOR_FILE
extern int flag_ms_extensions;
#else
  int x_flag_ms_extensions;
#define flag_ms_extensions global_options.x_flag_ms_extensions
#endif
#ifdef GENERATOR_FILE
extern int flag_mudflap;
#else
  int x_flag_mudflap;
#define flag_mudflap global_options.x_flag_mudflap
#endif
#ifdef GENERATOR_FILE
extern int flag_mudflap_ignore_reads;
#else
  int x_flag_mudflap_ignore_reads;
#define flag_mudflap_ignore_reads global_options.x_flag_mudflap_ignore_reads
#endif
#ifdef GENERATOR_FILE
extern int flag_nil_receivers;
#else
  int x_flag_nil_receivers;
#define flag_nil_receivers global_options.x_flag_nil_receivers
#endif
#ifdef GENERATOR_FILE
extern int flag_non_call_exceptions;
#else
  int x_flag_non_call_exceptions;
#define flag_non_call_exceptions global_options.x_flag_non_call_exceptions
#endif
#ifdef GENERATOR_FILE
extern int flag_no_nonansi_builtin;
#else
  int x_flag_no_nonansi_builtin;
#define flag_no_nonansi_builtin global_options.x_flag_no_nonansi_builtin
#endif
#ifdef GENERATOR_FILE
extern int flag_nothrow_opt;
#else
  int x_flag_nothrow_opt;
#define flag_nothrow_opt global_options.x_flag_nothrow_opt
#endif
#ifdef GENERATOR_FILE
extern int flag_objc_abi;
#else
  int x_flag_objc_abi;
#define flag_objc_abi global_options.x_flag_objc_abi
#endif
#ifdef GENERATOR_FILE
extern int flag_objc_call_cxx_cdtors;
#else
  int x_flag_objc_call_cxx_cdtors;
#define flag_objc_call_cxx_cdtors global_options.x_flag_objc_call_cxx_cdtors
#endif
#ifdef GENERATOR_FILE
extern int flag_objc_direct_dispatch;
#else
  int x_flag_objc_direct_dispatch;
#define flag_objc_direct_dispatch global_options.x_flag_objc_direct_dispatch
#endif
#ifdef GENERATOR_FILE
extern int flag_objc_exceptions;
#else
  int x_flag_objc_exceptions;
#define flag_objc_exceptions global_options.x_flag_objc_exceptions
#endif
#ifdef GENERATOR_FILE
extern int flag_objc_gc;
#else
  int x_flag_objc_gc;
#define flag_objc_gc global_options.x_flag_objc_gc
#endif
#ifdef GENERATOR_FILE
extern int flag_objc_nilcheck;
#else
  int x_flag_objc_nilcheck;
#define flag_objc_nilcheck global_options.x_flag_objc_nilcheck
#endif
#ifdef GENERATOR_FILE
extern int flag_objc_sjlj_exceptions;
#else
  int x_flag_objc_sjlj_exceptions;
#define flag_objc_sjlj_exceptions global_options.x_flag_objc_sjlj_exceptions
#endif
#ifdef GENERATOR_FILE
extern int flag_objc1_only;
#else
  int x_flag_objc1_only;
#define flag_objc1_only global_options.x_flag_objc1_only
#endif
#ifdef GENERATOR_FILE
extern int flag_omit_frame_pointer;
#else
  int x_flag_omit_frame_pointer;
#define flag_omit_frame_pointer global_options.x_flag_omit_frame_pointer
#endif
#ifdef GENERATOR_FILE
extern int flag_openmp;
#else
  int x_flag_openmp;
#define flag_openmp global_options.x_flag_openmp
#endif
#ifdef GENERATOR_FILE
extern int flag_regmove;
#else
  int x_flag_regmove;
#define flag_regmove global_options.x_flag_regmove
#endif
#ifdef GENERATOR_FILE
extern int flag_optimize_sibling_calls;
#else
  int x_flag_optimize_sibling_calls;
#define flag_optimize_sibling_calls global_options.x_flag_optimize_sibling_calls
#endif
#ifdef GENERATOR_FILE
extern int flag_optimize_sci;
#else
  int x_flag_optimize_sci;
#define flag_optimize_sci global_options.x_flag_optimize_sci
#endif
#ifdef GENERATOR_FILE
extern int flag_pack_struct;
#else
  int x_flag_pack_struct;
#define flag_pack_struct global_options.x_flag_pack_struct
#endif
#ifdef GENERATOR_FILE
extern int flag_partial_inlining;
#else
  int x_flag_partial_inlining;
#define flag_partial_inlining global_options.x_flag_partial_inlining
#endif
#ifdef GENERATOR_FILE
extern int flag_pcc_struct_return;
#else
  int x_flag_pcc_struct_return;
#define flag_pcc_struct_return global_options.x_flag_pcc_struct_return
#endif
#ifdef GENERATOR_FILE
extern int flag_peel_loops;
#else
  int x_flag_peel_loops;
#define flag_peel_loops global_options.x_flag_peel_loops
#endif
#ifdef GENERATOR_FILE
extern int flag_no_peephole;
#else
  int x_flag_no_peephole;
#define flag_no_peephole global_options.x_flag_no_peephole
#endif
#ifdef GENERATOR_FILE
extern int flag_peephole2;
#else
  int x_flag_peephole2;
#define flag_peephole2 global_options.x_flag_peephole2
#endif
#ifdef GENERATOR_FILE
extern int flag_plan9_extensions;
#else
  int x_flag_plan9_extensions;
#define flag_plan9_extensions global_options.x_flag_plan9_extensions
#endif
#ifdef GENERATOR_FILE
extern int post_ipa_mem_report;
#else
  int x_post_ipa_mem_report;
#define post_ipa_mem_report global_options.x_post_ipa_mem_report
#endif
#ifdef GENERATOR_FILE
extern int pre_ipa_mem_report;
#else
  int x_pre_ipa_mem_report;
#define pre_ipa_mem_report global_options.x_pre_ipa_mem_report
#endif
#ifdef GENERATOR_FILE
extern int flag_predictive_commoning;
#else
  int x_flag_predictive_commoning;
#define flag_predictive_commoning global_options.x_flag_predictive_commoning
#endif
#ifdef GENERATOR_FILE
extern int flag_prefetch_loop_arrays;
#else
  int x_flag_prefetch_loop_arrays;
#define flag_prefetch_loop_arrays global_options.x_flag_prefetch_loop_arrays
#endif
#ifdef GENERATOR_FILE
extern int flag_pretty_templates;
#else
  int x_flag_pretty_templates;
#define flag_pretty_templates global_options.x_flag_pretty_templates
#endif
#ifdef GENERATOR_FILE
extern int profile_flag;
#else
  int x_profile_flag;
#define profile_flag global_options.x_profile_flag
#endif
#ifdef GENERATOR_FILE
extern int profile_arc_flag;
#else
  int x_profile_arc_flag;
#define profile_arc_flag global_options.x_profile_arc_flag
#endif
#ifdef GENERATOR_FILE
extern int flag_profile_correction;
#else
  int x_flag_profile_correction;
#define flag_profile_correction global_options.x_flag_profile_correction
#endif
#ifdef GENERATOR_FILE
extern const char *profile_data_prefix;
#else
  const char *x_profile_data_prefix;
#define profile_data_prefix global_options.x_profile_data_prefix
#endif
#ifdef GENERATOR_FILE
extern int flag_profile_use;
#else
  int x_flag_profile_use;
#define flag_profile_use global_options.x_flag_profile_use
#endif
#ifdef GENERATOR_FILE
extern int flag_profile_values;
#else
  int x_flag_profile_values;
#define flag_profile_values global_options.x_flag_profile_values
#endif
#ifdef GENERATOR_FILE
extern int flag_reciprocal_math;
#else
  int x_flag_reciprocal_math;
#define flag_reciprocal_math global_options.x_flag_reciprocal_math
#endif
#ifdef GENERATOR_FILE
extern int flag_record_gcc_switches;
#else
  int x_flag_record_gcc_switches;
#define flag_record_gcc_switches global_options.x_flag_record_gcc_switches
#endif
#ifdef GENERATOR_FILE
extern int flag_reduced_reflection;
#else
  int x_flag_reduced_reflection;
#define flag_reduced_reflection global_options.x_flag_reduced_reflection
#endif
#ifdef GENERATOR_FILE
extern int flag_rename_registers;
#else
  int x_flag_rename_registers;
#define flag_rename_registers global_options.x_flag_rename_registers
#endif
#ifdef GENERATOR_FILE
extern int flag_reorder_blocks;
#else
  int x_flag_reorder_blocks;
#define flag_reorder_blocks global_options.x_flag_reorder_blocks
#endif
#ifdef GENERATOR_FILE
extern int flag_reorder_blocks_and_partition;
#else
  int x_flag_reorder_blocks_and_partition;
#define flag_reorder_blocks_and_partition global_options.x_flag_reorder_blocks_and_partition
#endif
#ifdef GENERATOR_FILE
extern int flag_reorder_functions;
#else
  int x_flag_reorder_functions;
#define flag_reorder_functions global_options.x_flag_reorder_functions
#endif
#ifdef GENERATOR_FILE
extern int flag_replace_objc_classes;
#else
  int x_flag_replace_objc_classes;
#define flag_replace_objc_classes global_options.x_flag_replace_objc_classes
#endif
#ifdef GENERATOR_FILE
extern int go_require_return_statement;
#else
  int x_go_require_return_statement;
#define go_require_return_statement global_options.x_go_require_return_statement
#endif
#ifdef GENERATOR_FILE
extern int flag_rerun_cse_after_loop;
#else
  int x_flag_rerun_cse_after_loop;
#define flag_rerun_cse_after_loop global_options.x_flag_rerun_cse_after_loop
#endif
#ifdef GENERATOR_FILE
extern int flag_resched_modulo_sched;
#else
  int x_flag_resched_modulo_sched;
#define flag_resched_modulo_sched global_options.x_flag_resched_modulo_sched
#endif
#ifdef GENERATOR_FILE
extern int flag_rounding_math;
#else
  int x_flag_rounding_math;
#define flag_rounding_math global_options.x_flag_rounding_math
#endif
#ifdef GENERATOR_FILE
extern int flag_rtti;
#else
  int x_flag_rtti;
#define flag_rtti global_options.x_flag_rtti
#endif
#ifdef GENERATOR_FILE
extern int flag_sched_critical_path_heuristic;
#else
  int x_flag_sched_critical_path_heuristic;
#define flag_sched_critical_path_heuristic global_options.x_flag_sched_critical_path_heuristic
#endif
#ifdef GENERATOR_FILE
extern int flag_sched_dep_count_heuristic;
#else
  int x_flag_sched_dep_count_heuristic;
#define flag_sched_dep_count_heuristic global_options.x_flag_sched_dep_count_heuristic
#endif
#ifdef GENERATOR_FILE
extern int flag_sched_group_heuristic;
#else
  int x_flag_sched_group_heuristic;
#define flag_sched_group_heuristic global_options.x_flag_sched_group_heuristic
#endif
#ifdef GENERATOR_FILE
extern int flag_schedule_interblock;
#else
  int x_flag_schedule_interblock;
#define flag_schedule_interblock global_options.x_flag_schedule_interblock
#endif
#ifdef GENERATOR_FILE
extern int flag_sched_last_insn_heuristic;
#else
  int x_flag_sched_last_insn_heuristic;
#define flag_sched_last_insn_heuristic global_options.x_flag_sched_last_insn_heuristic
#endif
#ifdef GENERATOR_FILE
extern int flag_sched_pressure;
#else
  int x_flag_sched_pressure;
#define flag_sched_pressure global_options.x_flag_sched_pressure
#endif
#ifdef GENERATOR_FILE
extern int flag_sched_rank_heuristic;
#else
  int x_flag_sched_rank_heuristic;
#define flag_sched_rank_heuristic global_options.x_flag_sched_rank_heuristic
#endif
#ifdef GENERATOR_FILE
extern int flag_schedule_speculative;
#else
  int x_flag_schedule_speculative;
#define flag_schedule_speculative global_options.x_flag_schedule_speculative
#endif
#ifdef GENERATOR_FILE
extern int flag_sched_spec_insn_heuristic;
#else
  int x_flag_sched_spec_insn_heuristic;
#define flag_sched_spec_insn_heuristic global_options.x_flag_sched_spec_insn_heuristic
#endif
#ifdef GENERATOR_FILE
extern int flag_schedule_speculative_load;
#else
  int x_flag_schedule_speculative_load;
#define flag_schedule_speculative_load global_options.x_flag_schedule_speculative_load
#endif
#ifdef GENERATOR_FILE
extern int flag_schedule_speculative_load_dangerous;
#else
  int x_flag_schedule_speculative_load_dangerous;
#define flag_schedule_speculative_load_dangerous global_options.x_flag_schedule_speculative_load_dangerous
#endif
#ifdef GENERATOR_FILE
extern int flag_sched_stalled_insns;
#else
  int x_flag_sched_stalled_insns;
#define flag_sched_stalled_insns global_options.x_flag_sched_stalled_insns
#endif
#ifdef GENERATOR_FILE
extern int flag_sched_stalled_insns_dep;
#else
  int x_flag_sched_stalled_insns_dep;
#define flag_sched_stalled_insns_dep global_options.x_flag_sched_stalled_insns_dep
#endif
#ifdef GENERATOR_FILE
extern int sched_verbose_param;
#else
  int x_sched_verbose_param;
#define sched_verbose_param global_options.x_sched_verbose_param
#endif
#ifdef GENERATOR_FILE
extern int flag_sched2_use_superblocks;
#else
  int x_flag_sched2_use_superblocks;
#define flag_sched2_use_superblocks global_options.x_flag_sched2_use_superblocks
#endif
#ifdef GENERATOR_FILE
extern int flag_schedule_insns;
#else
  int x_flag_schedule_insns;
#define flag_schedule_insns global_options.x_flag_schedule_insns
#endif
#ifdef GENERATOR_FILE
extern int flag_schedule_insns_after_reload;
#else
  int x_flag_schedule_insns_after_reload;
#define flag_schedule_insns_after_reload global_options.x_flag_schedule_insns_after_reload
#endif
#ifdef GENERATOR_FILE
extern int flag_section_anchors;
#else
  int x_flag_section_anchors;
#define flag_section_anchors global_options.x_flag_section_anchors
#endif
#ifdef GENERATOR_FILE
extern int flag_sel_sched_pipelining;
#else
  int x_flag_sel_sched_pipelining;
#define flag_sel_sched_pipelining global_options.x_flag_sel_sched_pipelining
#endif
#ifdef GENERATOR_FILE
extern int flag_sel_sched_pipelining_outer_loops;
#else
  int x_flag_sel_sched_pipelining_outer_loops;
#define flag_sel_sched_pipelining_outer_loops global_options.x_flag_sel_sched_pipelining_outer_loops
#endif
#ifdef GENERATOR_FILE
extern int flag_sel_sched_reschedule_pipelined;
#else
  int x_flag_sel_sched_reschedule_pipelined;
#define flag_sel_sched_reschedule_pipelined global_options.x_flag_sel_sched_reschedule_pipelined
#endif
#ifdef GENERATOR_FILE
extern int flag_selective_scheduling;
#else
  int x_flag_selective_scheduling;
#define flag_selective_scheduling global_options.x_flag_selective_scheduling
#endif
#ifdef GENERATOR_FILE
extern int flag_selective_scheduling2;
#else
  int x_flag_selective_scheduling2;
#define flag_selective_scheduling2 global_options.x_flag_selective_scheduling2
#endif
#ifdef GENERATOR_FILE
extern int flag_short_double;
#else
  int x_flag_short_double;
#define flag_short_double global_options.x_flag_short_double
#endif
#ifdef GENERATOR_FILE
extern int flag_short_enums;
#else
  int x_flag_short_enums;
#define flag_short_enums global_options.x_flag_short_enums
#endif
#ifdef GENERATOR_FILE
extern int flag_short_wchar;
#else
  int x_flag_short_wchar;
#define flag_short_wchar global_options.x_flag_short_wchar
#endif
#ifdef GENERATOR_FILE
extern int flag_show_column;
#else
  int x_flag_show_column;
#define flag_show_column global_options.x_flag_show_column
#endif
#ifdef GENERATOR_FILE
extern int flag_signaling_nans;
#else
  int x_flag_signaling_nans;
#define flag_signaling_nans global_options.x_flag_signaling_nans
#endif
#ifdef GENERATOR_FILE
extern int flag_signed_bitfields;
#else
  int x_flag_signed_bitfields;
#define flag_signed_bitfields global_options.x_flag_signed_bitfields
#endif
#ifdef GENERATOR_FILE
extern int flag_signed_char;
#else
  int x_flag_signed_char;
#define flag_signed_char global_options.x_flag_signed_char
#endif
#ifdef GENERATOR_FILE
extern int flag_signed_zeros;
#else
  int x_flag_signed_zeros;
#define flag_signed_zeros global_options.x_flag_signed_zeros
#endif
#ifdef GENERATOR_FILE
extern int flag_single_precision_constant;
#else
  int x_flag_single_precision_constant;
#define flag_single_precision_constant global_options.x_flag_single_precision_constant
#endif
#ifdef GENERATOR_FILE
extern int flag_split_ivs_in_unroller;
#else
  int x_flag_split_ivs_in_unroller;
#define flag_split_ivs_in_unroller global_options.x_flag_split_ivs_in_unroller
#endif
#ifdef GENERATOR_FILE
extern int flag_split_stack;
#else
  int x_flag_split_stack;
#define flag_split_stack global_options.x_flag_split_stack
#endif
#ifdef GENERATOR_FILE
extern int flag_split_wide_types;
#else
  int x_flag_split_wide_types;
#define flag_split_wide_types global_options.x_flag_split_wide_types
#endif
#ifdef GENERATOR_FILE
extern int flag_stack_protect;
#else
  int x_flag_stack_protect;
#define flag_stack_protect global_options.x_flag_stack_protect
#endif
#ifdef GENERATOR_FILE
extern int flag_stack_usage;
#else
  int x_flag_stack_usage;
#define flag_stack_usage global_options.x_flag_stack_usage
#endif
#ifdef GENERATOR_FILE
extern int flag_detailed_statistics;
#else
  int x_flag_detailed_statistics;
#define flag_detailed_statistics global_options.x_flag_detailed_statistics
#endif
#ifdef GENERATOR_FILE
extern int flag_store_check;
#else
  int x_flag_store_check;
#define flag_store_check global_options.x_flag_store_check
#endif
#ifdef GENERATOR_FILE
extern int flag_strict_aliasing;
#else
  int x_flag_strict_aliasing;
#define flag_strict_aliasing global_options.x_flag_strict_aliasing
#endif
#ifdef GENERATOR_FILE
extern int flag_strict_enums;
#else
  int x_flag_strict_enums;
#define flag_strict_enums global_options.x_flag_strict_enums
#endif
#ifdef GENERATOR_FILE
extern int flag_strict_overflow;
#else
  int x_flag_strict_overflow;
#define flag_strict_overflow global_options.x_flag_strict_overflow
#endif
#ifdef GENERATOR_FILE
extern int flag_strict_volatile_bitfields;
#else
  int x_flag_strict_volatile_bitfields;
#define flag_strict_volatile_bitfields global_options.x_flag_strict_volatile_bitfields
#endif
#ifdef GENERATOR_FILE
extern int flag_syntax_only;
#else
  int x_flag_syntax_only;
#define flag_syntax_only global_options.x_flag_syntax_only
#endif
#ifdef GENERATOR_FILE
extern int flag_test_coverage;
#else
  int x_flag_test_coverage;
#define flag_test_coverage global_options.x_flag_test_coverage
#endif
#ifdef GENERATOR_FILE
extern int flag_thread_jumps;
#else
  int x_flag_thread_jumps;
#define flag_thread_jumps global_options.x_flag_thread_jumps
#endif
#ifdef GENERATOR_FILE
extern int flag_threadsafe_statics;
#else
  int x_flag_threadsafe_statics;
#define flag_threadsafe_statics global_options.x_flag_threadsafe_statics
#endif
#ifdef GENERATOR_FILE
extern int time_report;
#else
  int x_time_report;
#define time_report global_options.x_time_report
#endif
#ifdef GENERATOR_FILE
extern enum tls_model flag_tls_default;
#else
  enum tls_model x_flag_tls_default;
#define flag_tls_default global_options.x_flag_tls_default
#endif
#ifdef GENERATOR_FILE
extern int flag_toplevel_reorder;
#else
  int x_flag_toplevel_reorder;
#define flag_toplevel_reorder global_options.x_flag_toplevel_reorder
#endif
#ifdef GENERATOR_FILE
extern int flag_tracer;
#else
  int x_flag_tracer;
#define flag_tracer global_options.x_flag_tracer
#endif
#ifdef GENERATOR_FILE
extern int flag_trapping_math;
#else
  int x_flag_trapping_math;
#define flag_trapping_math global_options.x_flag_trapping_math
#endif
#ifdef GENERATOR_FILE
extern int flag_trapv;
#else
  int x_flag_trapv;
#define flag_trapv global_options.x_flag_trapv
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_bit_ccp;
#else
  int x_flag_tree_bit_ccp;
#define flag_tree_bit_ccp global_options.x_flag_tree_bit_ccp
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_builtin_call_dce;
#else
  int x_flag_tree_builtin_call_dce;
#define flag_tree_builtin_call_dce global_options.x_flag_tree_builtin_call_dce
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_ccp;
#else
  int x_flag_tree_ccp;
#define flag_tree_ccp global_options.x_flag_tree_ccp
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_ch;
#else
  int x_flag_tree_ch;
#define flag_tree_ch global_options.x_flag_tree_ch
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_copy_prop;
#else
  int x_flag_tree_copy_prop;
#define flag_tree_copy_prop global_options.x_flag_tree_copy_prop
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_copyrename;
#else
  int x_flag_tree_copyrename;
#define flag_tree_copyrename global_options.x_flag_tree_copyrename
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_cselim;
#else
  int x_flag_tree_cselim;
#define flag_tree_cselim global_options.x_flag_tree_cselim
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_dce;
#else
  int x_flag_tree_dce;
#define flag_tree_dce global_options.x_flag_tree_dce
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_dom;
#else
  int x_flag_tree_dom;
#define flag_tree_dom global_options.x_flag_tree_dom
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_dse;
#else
  int x_flag_tree_dse;
#define flag_tree_dse global_options.x_flag_tree_dse
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_forwprop;
#else
  int x_flag_tree_forwprop;
#define flag_tree_forwprop global_options.x_flag_tree_forwprop
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_fre;
#else
  int x_flag_tree_fre;
#define flag_tree_fre global_options.x_flag_tree_fre
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_loop_distribute_patterns;
#else
  int x_flag_tree_loop_distribute_patterns;
#define flag_tree_loop_distribute_patterns global_options.x_flag_tree_loop_distribute_patterns
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_loop_distribution;
#else
  int x_flag_tree_loop_distribution;
#define flag_tree_loop_distribution global_options.x_flag_tree_loop_distribution
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_loop_if_convert;
#else
  int x_flag_tree_loop_if_convert;
#define flag_tree_loop_if_convert global_options.x_flag_tree_loop_if_convert
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_loop_if_convert_stores;
#else
  int x_flag_tree_loop_if_convert_stores;
#define flag_tree_loop_if_convert_stores global_options.x_flag_tree_loop_if_convert_stores
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_loop_im;
#else
  int x_flag_tree_loop_im;
#define flag_tree_loop_im global_options.x_flag_tree_loop_im
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_loop_ivcanon;
#else
  int x_flag_tree_loop_ivcanon;
#define flag_tree_loop_ivcanon global_options.x_flag_tree_loop_ivcanon
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_loop_optimize;
#else
  int x_flag_tree_loop_optimize;
#define flag_tree_loop_optimize global_options.x_flag_tree_loop_optimize
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_live_range_split;
#else
  int x_flag_tree_live_range_split;
#define flag_tree_live_range_split global_options.x_flag_tree_live_range_split
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_parallelize_loops;
#else
  int x_flag_tree_parallelize_loops;
#define flag_tree_parallelize_loops global_options.x_flag_tree_parallelize_loops
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_phiprop;
#else
  int x_flag_tree_phiprop;
#define flag_tree_phiprop global_options.x_flag_tree_phiprop
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_pre;
#else
  int x_flag_tree_pre;
#define flag_tree_pre global_options.x_flag_tree_pre
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_pta;
#else
  int x_flag_tree_pta;
#define flag_tree_pta global_options.x_flag_tree_pta
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_reassoc;
#else
  int x_flag_tree_reassoc;
#define flag_tree_reassoc global_options.x_flag_tree_reassoc
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_scev_cprop;
#else
  int x_flag_tree_scev_cprop;
#define flag_tree_scev_cprop global_options.x_flag_tree_scev_cprop
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_sink;
#else
  int x_flag_tree_sink;
#define flag_tree_sink global_options.x_flag_tree_sink
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_slp_vectorize;
#else
  int x_flag_tree_slp_vectorize;
#define flag_tree_slp_vectorize global_options.x_flag_tree_slp_vectorize
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_sra;
#else
  int x_flag_tree_sra;
#define flag_tree_sra global_options.x_flag_tree_sra
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_switch_conversion;
#else
  int x_flag_tree_switch_conversion;
#define flag_tree_switch_conversion global_options.x_flag_tree_switch_conversion
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_ter;
#else
  int x_flag_tree_ter;
#define flag_tree_ter global_options.x_flag_tree_ter
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_vect_loop_version;
#else
  int x_flag_tree_vect_loop_version;
#define flag_tree_vect_loop_version global_options.x_flag_tree_vect_loop_version
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_vectorize;
#else
  int x_flag_tree_vectorize;
#define flag_tree_vectorize global_options.x_flag_tree_vectorize
#endif
#ifdef GENERATOR_FILE
extern int flag_tree_vrp;
#else
  int x_flag_tree_vrp;
#define flag_tree_vrp global_options.x_flag_tree_vrp
#endif
#ifdef GENERATOR_FILE
extern int flag_unit_at_a_time;
#else
  int x_flag_unit_at_a_time;
#define flag_unit_at_a_time global_options.x_flag_unit_at_a_time
#endif
#ifdef GENERATOR_FILE
extern int flag_unroll_all_loops;
#else
  int x_flag_unroll_all_loops;
#define flag_unroll_all_loops global_options.x_flag_unroll_all_loops
#endif
#ifdef GENERATOR_FILE
extern int flag_unroll_loops;
#else
  int x_flag_unroll_loops;
#define flag_unroll_loops global_options.x_flag_unroll_loops
#endif
#ifdef GENERATOR_FILE
extern int flag_unsafe_loop_optimizations;
#else
  int x_flag_unsafe_loop_optimizations;
#define flag_unsafe_loop_optimizations global_options.x_flag_unsafe_loop_optimizations
#endif
#ifdef GENERATOR_FILE
extern int flag_unsafe_math_optimizations;
#else
  int x_flag_unsafe_math_optimizations;
#define flag_unsafe_math_optimizations global_options.x_flag_unsafe_math_optimizations
#endif
#ifdef GENERATOR_FILE
extern int flag_unswitch_loops;
#else
  int x_flag_unswitch_loops;
#define flag_unswitch_loops global_options.x_flag_unswitch_loops
#endif
#ifdef GENERATOR_FILE
extern int flag_unwind_tables;
#else
  int x_flag_unwind_tables;
#define flag_unwind_tables global_options.x_flag_unwind_tables
#endif
#ifdef GENERATOR_FILE
extern int flag_use_atomic_builtins;
#else
  int x_flag_use_atomic_builtins;
#define flag_use_atomic_builtins global_options.x_flag_use_atomic_builtins
#endif
#ifdef GENERATOR_FILE
extern int flag_use_boehm_gc;
#else
  int x_flag_use_boehm_gc;
#define flag_use_boehm_gc global_options.x_flag_use_boehm_gc
#endif
#ifdef GENERATOR_FILE
extern int flag_use_cxa_atexit;
#else
  int x_flag_use_cxa_atexit;
#define flag_use_cxa_atexit global_options.x_flag_use_cxa_atexit
#endif
#ifdef GENERATOR_FILE
extern int flag_use_cxa_get_exception_ptr;
#else
  int x_flag_use_cxa_get_exception_ptr;
#define flag_use_cxa_get_exception_ptr global_options.x_flag_use_cxa_get_exception_ptr
#endif
#ifdef GENERATOR_FILE
extern int flag_use_divide_subroutine;
#else
  int x_flag_use_divide_subroutine;
#define flag_use_divide_subroutine global_options.x_flag_use_divide_subroutine
#endif
#ifdef GENERATOR_FILE
extern int flag_var_tracking;
#else
  int x_flag_var_tracking;
#define flag_var_tracking global_options.x_flag_var_tracking
#endif
#ifdef GENERATOR_FILE
extern int flag_var_tracking_assignments;
#else
  int x_flag_var_tracking_assignments;
#define flag_var_tracking_assignments global_options.x_flag_var_tracking_assignments
#endif
#ifdef GENERATOR_FILE
extern int flag_var_tracking_assignments_toggle;
#else
  int x_flag_var_tracking_assignments_toggle;
#define flag_var_tracking_assignments_toggle global_options.x_flag_var_tracking_assignments_toggle
#endif
#ifdef GENERATOR_FILE
extern int flag_var_tracking_uninit;
#else
  int x_flag_var_tracking_uninit;
#define flag_var_tracking_uninit global_options.x_flag_var_tracking_uninit
#endif
#ifdef GENERATOR_FILE
extern int flag_variable_expansion_in_unroller;
#else
  int x_flag_variable_expansion_in_unroller;
#define flag_variable_expansion_in_unroller global_options.x_flag_variable_expansion_in_unroller
#endif
#ifdef GENERATOR_FILE
extern int flag_vect_cost_model;
#else
  int x_flag_vect_cost_model;
#define flag_vect_cost_model global_options.x_flag_vect_cost_model
#endif
#ifdef GENERATOR_FILE
extern int flag_verbose_asm;
#else
  int x_flag_verbose_asm;
#define flag_verbose_asm global_options.x_flag_verbose_asm
#endif
#ifdef GENERATOR_FILE
extern int flag_visibility_ms_compat;
#else
  int x_flag_visibility_ms_compat;
#define flag_visibility_ms_compat global_options.x_flag_visibility_ms_compat
#endif
#ifdef GENERATOR_FILE
extern enum symbol_visibility default_visibility;
#else
  enum symbol_visibility x_default_visibility;
#define default_visibility global_options.x_default_visibility
#endif
#ifdef GENERATOR_FILE
extern int flag_value_profile_transformations;
#else
  int x_flag_value_profile_transformations;
#define flag_value_profile_transformations global_options.x_flag_value_profile_transformations
#endif
#ifdef GENERATOR_FILE
extern int flag_weak;
#else
  int x_flag_weak;
#define flag_weak global_options.x_flag_weak
#endif
#ifdef GENERATOR_FILE
extern int flag_web;
#else
  int x_flag_web;
#define flag_web global_options.x_flag_web
#endif
#ifdef GENERATOR_FILE
extern int flag_whole_program;
#else
  int x_flag_whole_program;
#define flag_whole_program global_options.x_flag_whole_program
#endif
#ifdef GENERATOR_FILE
extern int flag_working_directory;
#else
  int x_flag_working_directory;
#define flag_working_directory global_options.x_flag_working_directory
#endif
#ifdef GENERATOR_FILE
extern int flag_wpa;
#else
  int x_flag_wpa;
#define flag_wpa global_options.x_flag_wpa
#endif
#ifdef GENERATOR_FILE
extern int flag_wrapv;
#else
  int x_flag_wrapv;
#define flag_wrapv global_options.x_flag_wrapv
#endif
#ifdef GENERATOR_FILE
extern int flag_zee;
#else
  int x_flag_zee;
#define flag_zee global_options.x_flag_zee
#endif
#ifdef GENERATOR_FILE
extern int flag_zero_initialized_in_bss;
#else
  int x_flag_zero_initialized_in_bss;
#define flag_zero_initialized_in_bss global_options.x_flag_zero_initialized_in_bss
#endif
#ifdef GENERATOR_FILE
extern int flag_zero_link;
#else
  int x_flag_zero_link;
#define flag_zero_link global_options.x_flag_zero_link
#endif
#ifdef GENERATOR_FILE
extern int dwarf_version;
#else
  int x_dwarf_version;
#define dwarf_version global_options.x_dwarf_version
#endif
#ifdef GENERATOR_FILE
extern int flag_gen_declaration;
#else
  int x_flag_gen_declaration;
#define flag_gen_declaration global_options.x_flag_gen_declaration
#endif
#ifdef GENERATOR_FILE
extern int dwarf_strict;
#else
  int x_dwarf_strict;
#define dwarf_strict global_options.x_dwarf_strict
#endif
#ifdef GENERATOR_FILE
extern int flag_gtoggle;
#else
  int x_flag_gtoggle;
#define flag_gtoggle global_options.x_flag_gtoggle
#endif
#ifdef GENERATOR_FILE
extern const char *imultiarch;
#else
  const char *x_imultiarch;
#define imultiarch global_options.x_imultiarch
#endif
#ifdef GENERATOR_FILE
extern const char *plugindir_string;
#else
  const char *x_plugindir_string;
#define plugindir_string global_options.x_plugindir_string
#endif
#ifdef GENERATOR_FILE
extern int TARGET_MAD;
#else
  int x_TARGET_MAD;
#define TARGET_MAD global_options.x_TARGET_MAD
#endif
#ifdef GENERATOR_FILE
extern int flag_android;
#else
  int x_flag_android;
#define flag_android global_options.x_flag_android
#endif
#ifdef GENERATOR_FILE
extern const char *mips_arch_string;
#else
  const char *x_mips_arch_string;
#define mips_arch_string global_options.x_mips_arch_string
#endif
#ifdef GENERATOR_FILE
extern int linux_libc;
#else
  int x_linux_libc;
#define linux_libc global_options.x_linux_libc
#endif
#ifdef GENERATOR_FILE
extern int mips_branch_cost;
#else
  int x_mips_branch_cost;
#define mips_branch_cost global_options.x_mips_branch_cost
#endif
#ifdef GENERATOR_FILE
extern int TARGET_DEBUG_MODE;
#else
  int x_TARGET_DEBUG_MODE;
#define TARGET_DEBUG_MODE global_options.x_TARGET_DEBUG_MODE
#endif
#ifdef GENERATOR_FILE
extern int TARGET_DEBUG_D_MODE;
#else
  int x_TARGET_DEBUG_D_MODE;
#define TARGET_DEBUG_D_MODE global_options.x_TARGET_DEBUG_D_MODE
#endif
#ifdef GENERATOR_FILE
extern int TARGET_MDMX;
#else
  int x_TARGET_MDMX;
#define TARGET_MDMX global_options.x_TARGET_MDMX
#endif
#ifdef GENERATOR_FILE
extern int TARGET_EMBEDDED_DATA;
#else
  int x_TARGET_EMBEDDED_DATA;
#define TARGET_EMBEDDED_DATA global_options.x_TARGET_EMBEDDED_DATA
#endif
#ifdef GENERATOR_FILE
extern int TARGET_EXTERN_SDATA;
#else
  int x_TARGET_EXTERN_SDATA;
#define TARGET_EXTERN_SDATA global_options.x_TARGET_EXTERN_SDATA
#endif
#ifdef GENERATOR_FILE
extern int TARGET_FIX_SB1;
#else
  int x_TARGET_FIX_SB1;
#define TARGET_FIX_SB1 global_options.x_TARGET_FIX_SB1
#endif
#ifdef GENERATOR_FILE
extern int TARGET_FIX_VR4120;
#else
  int x_TARGET_FIX_VR4120;
#define TARGET_FIX_VR4120 global_options.x_TARGET_FIX_VR4120
#endif
#ifdef GENERATOR_FILE
extern int TARGET_FIX_VR4130;
#else
  int x_TARGET_FIX_VR4130;
#define TARGET_FIX_VR4130 global_options.x_TARGET_FIX_VR4130
#endif
#ifdef GENERATOR_FILE
extern int TARGET_4300_MUL_FIX;
#else
  int x_TARGET_4300_MUL_FIX;
#define TARGET_4300_MUL_FIX global_options.x_TARGET_4300_MUL_FIX
#endif
#ifdef GENERATOR_FILE
extern int TARGET_FLIP_MIPS16;
#else
  int x_TARGET_FLIP_MIPS16;
#define TARGET_FLIP_MIPS16 global_options.x_TARGET_FLIP_MIPS16
#endif
#ifdef GENERATOR_FILE
extern const char *mips_cache_flush_func;
#else
  const char *x_mips_cache_flush_func;
#define mips_cache_flush_func global_options.x_mips_cache_flush_func
#endif
#ifdef GENERATOR_FILE
extern int TARGET_GPOPT;
#else
  int x_TARGET_GPOPT;
#define TARGET_GPOPT global_options.x_TARGET_GPOPT
#endif
#ifdef GENERATOR_FILE
extern int TARGET_INTERLINK_MIPS16;
#else
  int x_TARGET_INTERLINK_MIPS16;
#define TARGET_INTERLINK_MIPS16 global_options.x_TARGET_INTERLINK_MIPS16
#endif
#ifdef GENERATOR_FILE
extern int TARGET_LOCAL_SDATA;
#else
  int x_TARGET_LOCAL_SDATA;
#define TARGET_LOCAL_SDATA global_options.x_TARGET_LOCAL_SDATA
#endif
#ifdef GENERATOR_FILE
extern int TARGET_LONG_CALLS;
#else
  int x_TARGET_LONG_CALLS;
#define TARGET_LONG_CALLS global_options.x_TARGET_LONG_CALLS
#endif
#ifdef GENERATOR_FILE
extern int TARGET_MCOUNT_RA_ADDRESS;
#else
  int x_TARGET_MCOUNT_RA_ADDRESS;
#define TARGET_MCOUNT_RA_ADDRESS global_options.x_TARGET_MCOUNT_RA_ADDRESS
#endif
#ifdef GENERATOR_FILE
extern int TARGET_MT;
#else
  int x_TARGET_MT;
#define TARGET_MT global_options.x_TARGET_MT
#endif
#ifdef GENERATOR_FILE
extern int TARGET_NO_FLOAT;
#else
  int x_TARGET_NO_FLOAT;
#define TARGET_NO_FLOAT global_options.x_TARGET_NO_FLOAT
#endif
#ifdef GENERATOR_FILE
extern int TARGET_PLT;
#else
  int x_TARGET_PLT;
#define TARGET_PLT global_options.x_TARGET_PLT
#endif
#ifdef GENERATOR_FILE
extern int TARGET_SHARED;
#else
  int x_TARGET_SHARED;
#define TARGET_SHARED global_options.x_TARGET_SHARED
#endif
#ifdef GENERATOR_FILE
extern int TARGET_SYM32;
#else
  int x_TARGET_SYM32;
#define TARGET_SYM32 global_options.x_TARGET_SYM32
#endif
#ifdef GENERATOR_FILE
extern const char *mips_tune_string;
#else
  const char *x_mips_tune_string;
#define mips_tune_string global_options.x_mips_tune_string
#endif
#ifdef GENERATOR_FILE
extern int TARGET_UNINIT_CONST_IN_RODATA;
#else
  int x_TARGET_UNINIT_CONST_IN_RODATA;
#define TARGET_UNINIT_CONST_IN_RODATA global_options.x_TARGET_UNINIT_CONST_IN_RODATA
#endif
#ifdef GENERATOR_FILE
extern int TARGET_XGOT;
#else
  int x_TARGET_XGOT;
#define TARGET_XGOT global_options.x_TARGET_XGOT
#endif
#ifdef GENERATOR_FILE
extern const char *asm_file_name;
#else
  const char *x_asm_file_name;
#define asm_file_name global_options.x_asm_file_name
#endif
#ifdef GENERATOR_FILE
extern int pass_exit_codes;
#else
  int x_pass_exit_codes;
#define pass_exit_codes global_options.x_pass_exit_codes
#endif
#ifdef GENERATOR_FILE
extern int pedantic;
#else
  int x_pedantic;
#define pedantic global_options.x_pedantic
#endif
#ifdef GENERATOR_FILE
extern int flag_pedantic_errors;
#else
  int x_flag_pedantic_errors;
#define flag_pedantic_errors global_options.x_flag_pedantic_errors
#endif
#ifdef GENERATOR_FILE
extern int use_pipes;
#else
  int x_use_pipes;
#define use_pipes global_options.x_use_pipes
#endif
#ifdef GENERATOR_FILE
extern const char *print_file_name;
#else
  const char *x_print_file_name;
#define print_file_name global_options.x_print_file_name
#endif
#ifdef GENERATOR_FILE
extern int print_multi_directory;
#else
  int x_print_multi_directory;
#define print_multi_directory global_options.x_print_multi_directory
#endif
#ifdef GENERATOR_FILE
extern int print_multi_lib;
#else
  int x_print_multi_lib;
#define print_multi_lib global_options.x_print_multi_lib
#endif
#ifdef GENERATOR_FILE
extern int print_multi_os_directory;
#else
  int x_print_multi_os_directory;
#define print_multi_os_directory global_options.x_print_multi_os_directory
#endif
#ifdef GENERATOR_FILE
extern int print_multiarch;
#else
  int x_print_multiarch;
#define print_multiarch global_options.x_print_multiarch
#endif
#ifdef GENERATOR_FILE
extern const char *print_prog_name;
#else
  const char *x_print_prog_name;
#define print_prog_name global_options.x_print_prog_name
#endif
#ifdef GENERATOR_FILE
extern int print_search_dirs;
#else
  int x_print_search_dirs;
#define print_search_dirs global_options.x_print_search_dirs
#endif
#ifdef GENERATOR_FILE
extern int print_sysroot;
#else
  int x_print_sysroot;
#define print_sysroot global_options.x_print_sysroot
#endif
#ifdef GENERATOR_FILE
extern int print_sysroot_headers_suffix;
#else
  int x_print_sysroot_headers_suffix;
#define print_sysroot_headers_suffix global_options.x_print_sysroot_headers_suffix
#endif
#ifdef GENERATOR_FILE
extern int quiet_flag;
#else
  int x_quiet_flag;
#define quiet_flag global_options.x_quiet_flag
#endif
#ifdef GENERATOR_FILE
extern int report_times;
#else
  int x_report_times;
#define report_times global_options.x_report_times
#endif
#ifdef GENERATOR_FILE
extern int flag_undef;
#else
  int x_flag_undef;
#define flag_undef global_options.x_flag_undef
#endif
#ifdef GENERATOR_FILE
extern int verbose_flag;
#else
  int x_verbose_flag;
#define verbose_flag global_options.x_verbose_flag
#endif
#ifdef GENERATOR_FILE
extern int version_flag;
#else
  int x_version_flag;
#define version_flag global_options.x_version_flag
#endif
#ifdef GENERATOR_FILE
extern int inhibit_warnings;
#else
  int x_inhibit_warnings;
#define inhibit_warnings global_options.x_inhibit_warnings
#endif
#ifdef GENERATOR_FILE
extern const char *wrapper_string;
#else
  const char *x_wrapper_string;
#define wrapper_string global_options.x_wrapper_string
#endif
#ifndef GENERATOR_FILE
  const char *x_VAR_mabi_;
#define x_VAR_mabi_ do_not_use
#endif
#ifndef GENERATOR_FILE
  const char *x_VAR_mcode_readable_;
#define x_VAR_mcode_readable_ do_not_use
#endif
#ifndef GENERATOR_FILE
  const char *x_VAR_mips;
#define x_VAR_mips do_not_use
#endif
#ifndef GENERATOR_FILE
  int x_VAR_mmips_tfile;
#define x_VAR_mmips_tfile do_not_use
#endif
#ifndef GENERATOR_FILE
  int x_VAR_mno_flush_func;
#define x_VAR_mno_flush_func do_not_use
#endif
#ifndef GENERATOR_FILE
  const char *x_VAR_mr10k_cache_barrier_;
#define x_VAR_mr10k_cache_barrier_ do_not_use
#endif
#ifndef GENERATOR_FILE
  bool frontend_set_flag_associative_math;
#endif
#ifndef GENERATOR_FILE
  bool frontend_set_flag_cx_limited_range;
#endif
#ifndef GENERATOR_FILE
  bool frontend_set_flag_finite_math_only;
#endif
#ifndef GENERATOR_FILE
  bool frontend_set_flag_errno_math;
#endif
#ifndef GENERATOR_FILE
  bool frontend_set_flag_reciprocal_math;
#endif
#ifndef GENERATOR_FILE
  bool frontend_set_flag_rounding_math;
#endif
#ifndef GENERATOR_FILE
  bool frontend_set_flag_signaling_nans;
#endif
#ifndef GENERATOR_FILE
  bool frontend_set_flag_signed_zeros;
#endif
#ifndef GENERATOR_FILE
  bool frontend_set_flag_trapping_math;
#endif
#ifndef GENERATOR_FILE
  bool frontend_set_flag_unsafe_math_optimizations;
#endif
#ifndef GENERATOR_FILE
};
extern struct gcc_options global_options;
extern const struct gcc_options global_options_init;
extern struct gcc_options global_options_set;
#define target_flags_explicit global_options_set.x_target_flags
#endif
#endif

#if !defined(GCC_DRIVER) && !defined(IN_LIBGCC2) && !defined(IN_TARGET_LIBS)

/* Structure to save/restore optimization and target specific options.  */
struct GTY(()) cl_optimization
{
  int x_align_functions;
  int x_align_jumps;
  int x_align_labels;
  int x_align_loops;
  int x_flag_sched_stalled_insns;
  int x_flag_sched_stalled_insns_dep;
  enum fp_contract_mode x_flag_fp_contract_mode;
  unsigned char x_optimize;
  unsigned char x_optimize_size;
  signed char x_flag_asynchronous_unwind_tables;
  signed char x_flag_branch_on_count_reg;
  signed char x_flag_branch_probabilities;
  signed char x_flag_branch_target_load_optimize;
  signed char x_flag_branch_target_load_optimize2;
  signed char x_flag_btr_bb_exclusive;
  signed char x_flag_caller_saves;
  signed char x_flag_combine_stack_adjustments;
  signed char x_flag_no_common;
  signed char x_flag_compare_elim_after_reload;
  signed char x_flag_conserve_stack;
  signed char x_flag_cprop_registers;
  signed char x_flag_crossjumping;
  signed char x_flag_cse_follow_jumps;
  signed char x_flag_cx_fortran_rules;
  signed char x_flag_cx_limited_range;
  signed char x_flag_data_sections;
  signed char x_flag_dce;
  signed char x_flag_defer_pop;
  signed char x_flag_delayed_branch;
  signed char x_flag_delete_null_pointer_checks;
  signed char x_flag_devirtualize;
  signed char x_flag_dse;
  signed char x_flag_early_inlining;
  signed char x_flag_exceptions;
  signed char x_flag_expensive_optimizations;
  signed char x_flag_finite_math_only;
  signed char x_flag_float_store;
  signed char x_flag_forward_propagate;
  signed char x_flag_gcse;
  signed char x_flag_gcse_after_reload;
  signed char x_flag_gcse_las;
  signed char x_flag_gcse_lm;
  signed char x_flag_gcse_sm;
  signed char x_flag_graphite_identity;
  signed char x_flag_guess_branch_prob;
  signed char x_flag_if_conversion;
  signed char x_flag_if_conversion2;
  signed char x_flag_inline_functions;
  signed char x_flag_inline_functions_called_once;
  signed char x_flag_inline_small_functions;
  signed char x_flag_ipa_cp;
  signed char x_flag_ipa_cp_clone;
  signed char x_flag_ipa_matrix_reorg;
  signed char x_flag_ipa_profile;
  signed char x_flag_ipa_pta;
  signed char x_flag_ipa_pure_const;
  signed char x_flag_ipa_reference;
  signed char x_flag_ipa_sra;
  signed char x_flag_ivopts;
  signed char x_flag_jump_tables;
  signed char x_flag_loop_block;
  signed char x_flag_loop_flatten;
  signed char x_flag_loop_interchange;
  signed char x_flag_loop_parallelize_all;
  signed char x_flag_loop_strip_mine;
  signed char x_flag_lto_report;
  signed char x_flag_ltrans;
  signed char x_flag_errno_math;
  signed char x_flag_merge_constants;
  signed char x_flag_modulo_sched;
  signed char x_flag_move_loop_invariants;
  signed char x_flag_non_call_exceptions;
  signed char x_flag_nothrow_opt;
  signed char x_flag_omit_frame_pointer;
  signed char x_flag_regmove;
  signed char x_flag_optimize_sibling_calls;
  signed char x_flag_pack_struct;
  signed char x_flag_peel_loops;
  signed char x_flag_no_peephole;
  signed char x_flag_peephole2;
  signed char x_flag_predictive_commoning;
  signed char x_flag_prefetch_loop_arrays;
  signed char x_flag_pcc_struct_return;
  signed char x_flag_rename_registers;
  signed char x_flag_reorder_blocks;
  signed char x_flag_reorder_blocks_and_partition;
  signed char x_flag_reorder_functions;
  signed char x_flag_rerun_cse_after_loop;
  signed char x_flag_resched_modulo_sched;
  signed char x_flag_rounding_math;
  signed char x_flag_rtti;
  signed char x_flag_sched_critical_path_heuristic;
  signed char x_flag_sched_dep_count_heuristic;
  signed char x_flag_sched_group_heuristic;
  signed char x_flag_schedule_interblock;
  signed char x_flag_sched_last_insn_heuristic;
  signed char x_flag_sched_pressure;
  signed char x_flag_sched_rank_heuristic;
  signed char x_flag_schedule_speculative;
  signed char x_flag_sched_spec_insn_heuristic;
  signed char x_flag_schedule_speculative_load;
  signed char x_flag_schedule_speculative_load_dangerous;
  signed char x_flag_sched2_use_superblocks;
  signed char x_flag_schedule_insns;
  signed char x_flag_schedule_insns_after_reload;
  signed char x_flag_section_anchors;
  signed char x_flag_sel_sched_pipelining;
  signed char x_flag_sel_sched_pipelining_outer_loops;
  signed char x_flag_sel_sched_reschedule_pipelined;
  signed char x_flag_selective_scheduling;
  signed char x_flag_selective_scheduling2;
  signed char x_flag_short_double;
  signed char x_flag_short_enums;
  signed char x_flag_short_wchar;
  signed char x_flag_signaling_nans;
  signed char x_flag_signed_zeros;
  signed char x_flag_single_precision_constant;
  signed char x_flag_split_ivs_in_unroller;
  signed char x_flag_split_wide_types;
  signed char x_flag_strict_aliasing;
  signed char x_flag_strict_enums;
  signed char x_flag_thread_jumps;
  signed char x_flag_threadsafe_statics;
  signed char x_flag_toplevel_reorder;
  signed char x_flag_trapping_math;
  signed char x_flag_trapv;
  signed char x_flag_tree_bit_ccp;
  signed char x_flag_tree_builtin_call_dce;
  signed char x_flag_tree_ccp;
  signed char x_flag_tree_ch;
  signed char x_flag_tree_copy_prop;
  signed char x_flag_tree_copyrename;
  signed char x_flag_tree_cselim;
  signed char x_flag_tree_dce;
  signed char x_flag_tree_dom;
  signed char x_flag_tree_dse;
  signed char x_flag_tree_forwprop;
  signed char x_flag_tree_fre;
  signed char x_flag_tree_loop_distribute_patterns;
  signed char x_flag_tree_loop_distribution;
  signed char x_flag_tree_loop_if_convert;
  signed char x_flag_tree_loop_if_convert_stores;
  signed char x_flag_tree_loop_im;
  signed char x_flag_tree_loop_ivcanon;
  signed char x_flag_tree_loop_optimize;
  signed char x_flag_tree_live_range_split;
  signed char x_flag_tree_phiprop;
  signed char x_flag_tree_pre;
  signed char x_flag_tree_pta;
  signed char x_flag_tree_reassoc;
  signed char x_flag_tree_scev_cprop;
  signed char x_flag_tree_sink;
  signed char x_flag_tree_slp_vectorize;
  signed char x_flag_tree_sra;
  signed char x_flag_tree_switch_conversion;
  signed char x_flag_tree_ter;
  signed char x_flag_tree_vect_loop_version;
  signed char x_flag_tree_vectorize;
  signed char x_flag_tree_vrp;
  signed char x_flag_unit_at_a_time;
  signed char x_flag_unroll_all_loops;
  signed char x_flag_unroll_loops;
  signed char x_flag_unsafe_loop_optimizations;
  signed char x_flag_unsafe_math_optimizations;
  signed char x_flag_unswitch_loops;
  signed char x_flag_unwind_tables;
  signed char x_flag_var_tracking;
  signed char x_flag_var_tracking_assignments;
  signed char x_flag_var_tracking_assignments_toggle;
  signed char x_flag_var_tracking_uninit;
  signed char x_flag_variable_expansion_in_unroller;
  signed char x_flag_vect_cost_model;
  signed char x_flag_value_profile_transformations;
  signed char x_flag_web;
  signed char x_flag_whole_program;
  signed char x_flag_wpa;
  signed char x_flag_wrapv;
};

/* Structure to save/restore selected target specific options.  */
struct GTY(()) cl_target_option
{
  int x_target_flags;
};


/* Save optimization variables into a structure.  */
extern void cl_optimization_save (struct cl_optimization *, struct gcc_options *);

/* Restore optimization variables from a structure.  */
extern void cl_optimization_restore (struct gcc_options *, struct cl_optimization *);

/* Print optimization variables from a structure.  */
extern void cl_optimization_print (FILE *, int, struct cl_optimization *);

/* Save selected option variables into a structure.  */
extern void cl_target_option_save (struct cl_target_option *, struct gcc_options *);

/* Restore selected option variables from a structure.  */
extern void cl_target_option_restore (struct gcc_options *, struct cl_target_option *);

/* Print target option variables from a structure.  */
extern void cl_target_option_print (FILE *, int, struct cl_target_option *);
#endif

#define MASK_ABICALLS (1 << 0)
#define OPTION_MASK_ANDROID (1 << 0)
#define MASK_BRANCHLIKELY (1 << 1)
#define MASK_CHECK_ZERO_DIV (1 << 2)
#define MASK_DIVIDE_BREAKS (1 << 3)
#define MASK_DSP (1 << 4)
#define MASK_DSPR2 (1 << 5)
#define MASK_BIG_ENDIAN (1 << 6)
#define MASK_EXPLICIT_RELOCS (1 << 7)
#define MASK_FIX_R10000 (1 << 8)
#define MASK_FIX_R4000 (1 << 9)
#define MASK_FIX_R4400 (1 << 10)
#define MASK_FP_EXCEPTIONS (1 << 11)
#define MASK_FLOAT64 (1 << 12)
#define MASK_FUSED_MADD (1 << 13)
#define MASK_64BIT (1 << 14)
#define MASK_MIPS16 (1 << 15)
#define MASK_MIPS3D (1 << 16)
#define MASK_LLSC (1 << 17)
#define MASK_LONG64 (1 << 18)
#define MASK_MEMCPY (1 << 19)
#define MASK_PAIRED_SINGLE_FLOAT (1 << 20)
#define MASK_RELAX_PIC_CALLS (1 << 21)
#define MASK_SINGLE_FLOAT (1 << 22)
#define MASK_SMARTMIPS (1 << 23)
#define MASK_SOFT_FLOAT_ABI (1 << 24)
#define MASK_SPLIT_ADDRESSES (1 << 25)
#define MASK_SYNCI (1 << 26)
#define MASK_VR4130_ALIGN (1 << 27)

#define TARGET_ABICALLS ((target_flags & MASK_ABICALLS) != 0)
#define OPTION_ANDROID ((flag_android & OPTION_MASK_ANDROID) != 0)
#define TARGET_BRANCHLIKELY ((target_flags & MASK_BRANCHLIKELY) != 0)
#define TARGET_CHECK_ZERO_DIV ((target_flags & MASK_CHECK_ZERO_DIV) != 0)
#define TARGET_DIVIDE_BREAKS ((target_flags & MASK_DIVIDE_BREAKS) != 0)
#define TARGET_DSP ((target_flags & MASK_DSP) != 0)
#define TARGET_DSPR2 ((target_flags & MASK_DSPR2) != 0)
#define TARGET_BIG_ENDIAN ((target_flags & MASK_BIG_ENDIAN) != 0)
#define TARGET_EXPLICIT_RELOCS ((target_flags & MASK_EXPLICIT_RELOCS) != 0)
#define TARGET_FIX_R10000 ((target_flags & MASK_FIX_R10000) != 0)
#define TARGET_FIX_R4000 ((target_flags & MASK_FIX_R4000) != 0)
#define TARGET_FIX_R4400 ((target_flags & MASK_FIX_R4400) != 0)
#define TARGET_FP_EXCEPTIONS ((target_flags & MASK_FP_EXCEPTIONS) != 0)
#define TARGET_FLOAT64 ((target_flags & MASK_FLOAT64) != 0)
#define TARGET_FUSED_MADD ((target_flags & MASK_FUSED_MADD) != 0)
#define TARGET_64BIT ((target_flags & MASK_64BIT) != 0)
#define TARGET_MIPS16 ((target_flags & MASK_MIPS16) != 0)
#define TARGET_MIPS3D ((target_flags & MASK_MIPS3D) != 0)
#define TARGET_LLSC ((target_flags & MASK_LLSC) != 0)
#define TARGET_LONG64 ((target_flags & MASK_LONG64) != 0)
#define TARGET_MEMCPY ((target_flags & MASK_MEMCPY) != 0)
#define TARGET_PAIRED_SINGLE_FLOAT ((target_flags & MASK_PAIRED_SINGLE_FLOAT) != 0)
#define TARGET_RELAX_PIC_CALLS ((target_flags & MASK_RELAX_PIC_CALLS) != 0)
#define TARGET_SINGLE_FLOAT ((target_flags & MASK_SINGLE_FLOAT) != 0)
#define TARGET_SMARTMIPS ((target_flags & MASK_SMARTMIPS) != 0)
#define TARGET_SOFT_FLOAT_ABI ((target_flags & MASK_SOFT_FLOAT_ABI) != 0)
#define TARGET_SPLIT_ADDRESSES ((target_flags & MASK_SPLIT_ADDRESSES) != 0)
#define TARGET_SYNCI ((target_flags & MASK_SYNCI) != 0)
#define TARGET_VR4130_ALIGN ((target_flags & MASK_VR4130_ALIGN) != 0)

#define TARGET_DIVIDE_TRAPS ((target_flags & MASK_DIVIDE_BREAKS) == 0)
#define TARGET_DOUBLE_FLOAT ((target_flags & MASK_SINGLE_FLOAT) == 0)
#define TARGET_LITTLE_ENDIAN ((target_flags & MASK_BIG_ENDIAN) == 0)
#define TARGET_HARD_FLOAT_ABI ((target_flags & MASK_SOFT_FLOAT_ABI) == 0)
#define TARGET_LONG32 ((target_flags & MASK_LONG64) == 0)

#define CL_Ada        (1 << 0)
#define CL_C          (1 << 1)
#define CL_CXX        (1 << 2)
#define CL_Fortran    (1 << 3)
#define CL_Go         (1 << 4)
#define CL_Java       (1 << 5)
#define CL_LTO        (1 << 6)
#define CL_ObjC       (1 << 7)
#define CL_ObjCXX     (1 << 8)
#define CL_LANG_ALL   ((1 << 9) - 1)

enum opt_code
{
  OPT____ = 0,                               /* -### */
  /* OPT__CLASSPATH = 1, */                  /* --CLASSPATH */
  /* OPT__all_warnings = 2, */               /* --all-warnings */
  /* OPT__ansi = 3, */                       /* --ansi */
  /* OPT__assemble = 4, */                   /* --assemble */
  /* OPT__assert = 5, */                     /* --assert */
  /* OPT__assert_ = 6, */                    /* --assert= */
  /* OPT__bootclasspath = 7, */              /* --bootclasspath */
  /* OPT__classpath = 8, */                  /* --classpath */
  /* OPT__comments = 9, */                   /* --comments */
  /* OPT__comments_in_macros = 10, */        /* --comments-in-macros */
  /* OPT__compile = 11, */                   /* --compile */
  /* OPT__coverage = 12, */                  /* --coverage */
  /* OPT__debug = 13, */                     /* --debug */
  /* OPT__define_macro = 14, */              /* --define-macro */
  /* OPT__define_macro_ = 15, */             /* --define-macro= */
  /* OPT__dependencies = 16, */              /* --dependencies */
  /* OPT__dump = 17, */                      /* --dump */
  /* OPT__dump_ = 18, */                     /* --dump= */
  /* OPT__dumpbase = 19, */                  /* --dumpbase */
  /* OPT__dumpdir = 20, */                   /* --dumpdir */
  /* OPT__encoding = 21, */                  /* --encoding */
  /* OPT__entry = 22, */                     /* --entry */
  /* OPT__entry_ = 23, */                    /* --entry= */
  /* OPT__extdirs = 24, */                   /* --extdirs */
  /* OPT__extra_warnings = 25, */            /* --extra-warnings */
  /* OPT__for_assembler = 26, */             /* --for-assembler */
  /* OPT__for_assembler_ = 27, */            /* --for-assembler= */
  /* OPT__for_linker = 28, */                /* --for-linker */
  /* OPT__for_linker_ = 29, */               /* --for-linker= */
  /* OPT__force_link = 30, */                /* --force-link */
  /* OPT__force_link_ = 31, */               /* --force-link= */
  OPT__help = 32,                            /* --help */
  OPT__help_ = 33,                           /* --help= */
  /* OPT__imacros = 34, */                   /* --imacros */
  /* OPT__imacros_ = 35, */                  /* --imacros= */
  /* OPT__include = 36, */                   /* --include */
  /* OPT__include_barrier = 37, */           /* --include-barrier */
  /* OPT__include_directory = 38, */         /* --include-directory */
  /* OPT__include_directory_after = 39, */   /* --include-directory-after */
  /* OPT__include_directory_after_ = 40, */  /* --include-directory-after= */
  /* OPT__include_directory_ = 41, */        /* --include-directory= */
  /* OPT__include_prefix = 42, */            /* --include-prefix */
  /* OPT__include_prefix_ = 43, */           /* --include-prefix= */
  /* OPT__include_with_prefix = 44, */       /* --include-with-prefix */
  /* OPT__include_with_prefix_after = 45, */ /* --include-with-prefix-after */
  /* OPT__include_with_prefix_after_ = 46, *//* --include-with-prefix-after= */
  /* OPT__include_with_prefix_before = 47, *//* --include-with-prefix-before */
  /* OPT__include_with_prefix_before_ = 48, *//* --include-with-prefix-before= */
  /* OPT__include_with_prefix_ = 49, */      /* --include-with-prefix= */
  /* OPT__include_ = 50, */                  /* --include= */
  /* OPT__language = 51, */                  /* --language */
  /* OPT__language_ = 52, */                 /* --language= */
  /* OPT__library_directory = 53, */         /* --library-directory */
  /* OPT__library_directory_ = 54, */        /* --library-directory= */
  /* OPT__no_canonical_prefixes = 55, */     /* --no-canonical-prefixes */
  /* OPT__no_integrated_cpp = 56, */         /* --no-integrated-cpp */
  /* OPT__no_line_commands = 57, */          /* --no-line-commands */
  /* OPT__no_standard_includes = 58, */      /* --no-standard-includes */
  /* OPT__no_standard_libraries = 59, */     /* --no-standard-libraries */
  /* OPT__no_warnings = 60, */               /* --no-warnings */
  /* OPT__optimize = 61, */                  /* --optimize */
  /* OPT__output = 62, */                    /* --output */
  /* OPT__output_class_directory = 63, */    /* --output-class-directory */
  /* OPT__output_class_directory_ = 64, */   /* --output-class-directory= */
  OPT__output_pch_ = 65,                     /* --output-pch= */
  /* OPT__output_ = 66, */                   /* --output= */
  OPT__param = 67,                           /* --param */
  /* OPT__param_ = 68, */                    /* --param= */
  /* OPT__pass_exit_codes = 69, */           /* --pass-exit-codes */
  /* OPT__pedantic = 70, */                  /* --pedantic */
  /* OPT__pedantic_errors = 71, */           /* --pedantic-errors */
  /* OPT__pie = 72, */                       /* --pie */
  /* OPT__pipe = 73, */                      /* --pipe */
  /* OPT__prefix = 74, */                    /* --prefix */
  /* OPT__prefix_ = 75, */                   /* --prefix= */
  /* OPT__preprocess = 76, */                /* --preprocess */
  /* OPT__print_file_name = 77, */           /* --print-file-name */
  /* OPT__print_file_name_ = 78, */          /* --print-file-name= */
  /* OPT__print_libgcc_file_name = 79, */    /* --print-libgcc-file-name */
  /* OPT__print_missing_file_dependencies = 80, *//* --print-missing-file-dependencies */
  /* OPT__print_multi_directory = 81, */     /* --print-multi-directory */
  /* OPT__print_multi_lib = 82, */           /* --print-multi-lib */
  /* OPT__print_multi_os_directory = 83, */  /* --print-multi-os-directory */
  /* OPT__print_multiarch = 84, */           /* --print-multiarch */
  /* OPT__print_prog_name = 85, */           /* --print-prog-name */
  /* OPT__print_prog_name_ = 86, */          /* --print-prog-name= */
  /* OPT__print_search_dirs = 87, */         /* --print-search-dirs */
  /* OPT__print_sysroot = 88, */             /* --print-sysroot */
  /* OPT__print_sysroot_headers_suffix = 89, *//* --print-sysroot-headers-suffix */
  /* OPT__profile = 90, */                   /* --profile */
  /* OPT__resource = 91, */                  /* --resource */
  /* OPT__resource_ = 92, */                 /* --resource= */
  /* OPT__save_temps = 93, */                /* --save-temps */
  /* OPT__shared = 94, */                    /* --shared */
  /* OPT__specs = 95, */                     /* --specs */
  /* OPT__specs_ = 96, */                    /* --specs= */
  /* OPT__static = 97, */                    /* --static */
  /* OPT__symbolic = 98, */                  /* --symbolic */
  /* OPT__sysroot = 99, */                   /* --sysroot */
  OPT__sysroot_ = 100,                       /* --sysroot= */
  OPT__target_help = 101,                    /* --target-help */
  /* OPT__time = 102, */                     /* --time */
  /* OPT__trace_includes = 103, */           /* --trace-includes */
  /* OPT__traditional = 104, */              /* --traditional */
  /* OPT__traditional_cpp = 105, */          /* --traditional-cpp */
  /* OPT__trigraphs = 106, */                /* --trigraphs */
  /* OPT__undefine_macro = 107, */           /* --undefine-macro */
  /* OPT__undefine_macro_ = 108, */          /* --undefine-macro= */
  /* OPT__user_dependencies = 109, */        /* --user-dependencies */
  /* OPT__verbose = 110, */                  /* --verbose */
  OPT__version = 111,                        /* --version */
  /* OPT__write_dependencies = 112, */       /* --write-dependencies */
  /* OPT__write_user_dependencies = 113, */  /* --write-user-dependencies */
  OPT_A = 114,                               /* -A */
  OPT_B = 115,                               /* -B */
  OPT_C = 116,                               /* -C */
  OPT_CC = 117,                              /* -CC */
  /* OPT_CLASSPATH = 118, */                 /* -CLASSPATH */
  OPT_D = 119,                               /* -D */
  OPT_E = 120,                               /* -E */
  OPT_EB = 121,                              /* -EB */
  OPT_EL = 122,                              /* -EL */
  OPT_F = 123,                               /* -F */
  OPT_G = 124,                               /* -G */
  OPT_H = 125,                               /* -H */
  OPT_I = 126,                               /* -I */
  OPT_J = 127,                               /* -J */
  OPT_L = 128,                               /* -L */
  OPT_M = 129,                               /* -M */
  OPT_MD = 130,                              /* -MD */
  OPT_MD_ = 131,                             /* -MD_ */
  OPT_MF = 132,                              /* -MF */
  OPT_MG = 133,                              /* -MG */
  OPT_MM = 134,                              /* -MM */
  OPT_MMD = 135,                             /* -MMD */
  OPT_MMD_ = 136,                            /* -MMD_ */
  OPT_MP = 137,                              /* -MP */
  OPT_MQ = 138,                              /* -MQ */
  OPT_MT = 139,                              /* -MT */
  OPT_N = 140,                               /* -N */
  OPT_O = 141,                               /* -O */
  OPT_Ofast = 142,                           /* -Ofast */
  OPT_Os = 143,                              /* -Os */
  OPT_P = 144,                               /* -P */
  OPT_Q = 145,                               /* -Q */
  OPT_Qn = 146,                              /* -Qn */
  OPT_Qy = 147,                              /* -Qy */
  OPT_R = 148,                               /* -R */
  OPT_S = 149,                               /* -S */
  OPT_T = 150,                               /* -T */
  OPT_Tbss = 151,                            /* -Tbss */
  OPT_Tbss_ = 152,                           /* -Tbss= */
  OPT_Tdata = 153,                           /* -Tdata */
  OPT_Tdata_ = 154,                          /* -Tdata= */
  OPT_Ttext = 155,                           /* -Ttext */
  OPT_Ttext_ = 156,                          /* -Ttext= */
  OPT_U = 157,                               /* -U */
  /* OPT_W = 158, */                         /* -W */
  OPT_Wa_ = 159,                             /* -Wa, */
  OPT_Wabi = 160,                            /* -Wabi */
  OPT_Waddress = 161,                        /* -Waddress */
  OPT_Waggregate_return = 162,               /* -Waggregate-return */
  OPT_Waliasing = 163,                       /* -Waliasing */
  OPT_Walign_commons = 164,                  /* -Walign-commons */
  OPT_Wall = 165,                            /* -Wall */
  OPT_Wall_deprecation = 166,                /* -Wall-deprecation */
  OPT_Wall_javadoc = 167,                    /* -Wall-javadoc */
  OPT_Wampersand = 168,                      /* -Wampersand */
  OPT_Warray_bounds = 169,                   /* -Warray-bounds */
  OPT_Warray_temporaries = 170,              /* -Warray-temporaries */
  OPT_Wassert_identifier = 171,              /* -Wassert-identifier */
  OPT_Wassign_intercept = 172,               /* -Wassign-intercept */
  OPT_Wattributes = 173,                     /* -Wattributes */
  OPT_Wbad_function_cast = 174,              /* -Wbad-function-cast */
  OPT_Wboxing = 175,                         /* -Wboxing */
  OPT_Wbuiltin_macro_redefined = 176,        /* -Wbuiltin-macro-redefined */
  OPT_Wc___compat = 177,                     /* -Wc++-compat */
  OPT_Wc__0x_compat = 178,                   /* -Wc++0x-compat */
  OPT_Wcast_align = 179,                     /* -Wcast-align */
  OPT_Wcast_qual = 180,                      /* -Wcast-qual */
  OPT_Wchar_concat = 181,                    /* -Wchar-concat */
  OPT_Wchar_subscripts = 182,                /* -Wchar-subscripts */
  OPT_Wcharacter_truncation = 183,           /* -Wcharacter-truncation */
  OPT_Wclobbered = 184,                      /* -Wclobbered */
  OPT_Wcomment = 185,                        /* -Wcomment */
  /* OPT_Wcomments = 186, */                 /* -Wcomments */
  OPT_Wcondition_assign = 187,               /* -Wcondition-assign */
  OPT_Wconstructor_name = 188,               /* -Wconstructor-name */
  OPT_Wconversion = 189,                     /* -Wconversion */
  OPT_Wconversion_extra = 190,               /* -Wconversion-extra */
  OPT_Wconversion_null = 191,                /* -Wconversion-null */
  OPT_Wcoverage_mismatch = 192,              /* -Wcoverage-mismatch */
  OPT_Wcpp = 193,                            /* -Wcpp */
  OPT_Wctor_dtor_privacy = 194,              /* -Wctor-dtor-privacy */
  OPT_Wdeclaration_after_statement = 195,    /* -Wdeclaration-after-statement */
  OPT_Wdep_ann = 196,                        /* -Wdep-ann */
  OPT_Wdeprecated = 197,                     /* -Wdeprecated */
  OPT_Wdeprecated_declarations = 198,        /* -Wdeprecated-declarations */
  OPT_Wdisabled_optimization = 199,          /* -Wdisabled-optimization */
  OPT_Wdiscouraged = 200,                    /* -Wdiscouraged */
  OPT_Wdiv_by_zero = 201,                    /* -Wdiv-by-zero */
  OPT_Wdouble_promotion = 202,               /* -Wdouble-promotion */
  OPT_Weffc__ = 203,                         /* -Weffc++ */
  OPT_Wempty_block = 204,                    /* -Wempty-block */
  OPT_Wempty_body = 205,                     /* -Wempty-body */
  OPT_Wendif_labels = 206,                   /* -Wendif-labels */
  OPT_Wenum_compare = 207,                   /* -Wenum-compare */
  OPT_Wenum_identifier = 208,                /* -Wenum-identifier */
  OPT_Wenum_switch = 209,                    /* -Wenum-switch */
  OPT_Werror = 210,                          /* -Werror */
  /* OPT_Werror_implicit_function_declaration = 211, *//* -Werror-implicit-function-declaration */
  OPT_Werror_maybe_reset = 212,              /* -Werror-maybe-reset */
  OPT_Werror_ = 213,                         /* -Werror= */
  OPT_Wextra = 214,                          /* -Wextra */
  OPT_Wextraneous_semicolon = 215,           /* -Wextraneous-semicolon */
  OPT_Wfallthrough = 216,                    /* -Wfallthrough */
  OPT_Wfatal_errors = 217,                   /* -Wfatal-errors */
  OPT_Wfield_hiding = 218,                   /* -Wfield-hiding */
  OPT_Wfinal_bound = 219,                    /* -Wfinal-bound */
  OPT_Wfinally = 220,                        /* -Wfinally */
  OPT_Wfloat_equal = 221,                    /* -Wfloat-equal */
  OPT_Wforbidden = 222,                      /* -Wforbidden */
  OPT_Wformat = 223,                         /* -Wformat */
  OPT_Wformat_contains_nul = 224,            /* -Wformat-contains-nul */
  OPT_Wformat_extra_args = 225,              /* -Wformat-extra-args */
  OPT_Wformat_nonliteral = 226,              /* -Wformat-nonliteral */
  OPT_Wformat_security = 227,                /* -Wformat-security */
  OPT_Wformat_y2k = 228,                     /* -Wformat-y2k */
  OPT_Wformat_zero_length = 229,             /* -Wformat-zero-length */
  OPT_Wformat_ = 230,                        /* -Wformat= */
  OPT_Wframe_larger_than_ = 231,             /* -Wframe-larger-than= */
  OPT_Whiding = 232,                         /* -Whiding */
  OPT_Wignored_qualifiers = 233,             /* -Wignored-qualifiers */
  OPT_Wimplicit = 234,                       /* -Wimplicit */
  OPT_Wimplicit_function_declaration = 235,  /* -Wimplicit-function-declaration */
  OPT_Wimplicit_int = 236,                   /* -Wimplicit-int */
  OPT_Wimplicit_interface = 237,             /* -Wimplicit-interface */
  OPT_Wimplicit_procedure = 238,             /* -Wimplicit-procedure */
  /* OPT_Wimport = 239, */                   /* -Wimport */
  OPT_Windirect_static = 240,                /* -Windirect-static */
  OPT_Winit_self = 241,                      /* -Winit-self */
  OPT_Winline = 242,                         /* -Winline */
  OPT_Wint_to_pointer_cast = 243,            /* -Wint-to-pointer-cast */
  OPT_Wintf_annotation = 244,                /* -Wintf-annotation */
  OPT_Wintf_non_inherited = 245,             /* -Wintf-non-inherited */
  OPT_Wintrinsic_shadow = 246,               /* -Wintrinsic-shadow */
  OPT_Wintrinsics_std = 247,                 /* -Wintrinsics-std */
  OPT_Winvalid_offsetof = 248,               /* -Winvalid-offsetof */
  OPT_Winvalid_pch = 249,                    /* -Winvalid-pch */
  OPT_Wjavadoc = 250,                        /* -Wjavadoc */
  OPT_Wjump_misses_init = 251,               /* -Wjump-misses-init */
  OPT_Wl_ = 252,                             /* -Wl, */
  /* OPT_Wlarger_than_ = 253, */             /* -Wlarger-than- */
  OPT_Wlarger_than_ = 254,                   /* -Wlarger-than= */
  OPT_Wline_truncation = 255,                /* -Wline-truncation */
  OPT_Wlocal_hiding = 256,                   /* -Wlocal-hiding */
  OPT_Wlogical_op = 257,                     /* -Wlogical-op */
  OPT_Wlong_long = 258,                      /* -Wlong-long */
  OPT_Wmain = 259,                           /* -Wmain */
  OPT_Wmasked_catch_block = 260,             /* -Wmasked-catch-block */
  OPT_Wmissing_braces = 261,                 /* -Wmissing-braces */
  OPT_Wmissing_declarations = 262,           /* -Wmissing-declarations */
  OPT_Wmissing_field_initializers = 263,     /* -Wmissing-field-initializers */
  OPT_Wmissing_format_attribute = 264,       /* -Wmissing-format-attribute */
  OPT_Wmissing_include_dirs = 265,           /* -Wmissing-include-dirs */
  OPT_Wmissing_noreturn = 266,               /* -Wmissing-noreturn */
  OPT_Wmissing_parameter_type = 267,         /* -Wmissing-parameter-type */
  OPT_Wmissing_prototypes = 268,             /* -Wmissing-prototypes */
  OPT_Wmudflap = 269,                        /* -Wmudflap */
  OPT_Wmultichar = 270,                      /* -Wmultichar */
  OPT_Wnested_externs = 271,                 /* -Wnested-externs */
  OPT_Wnls = 272,                            /* -Wnls */
  OPT_Wno_effect_assign = 273,               /* -Wno-effect-assign */
  OPT_Wnoexcept = 274,                       /* -Wnoexcept */
  OPT_Wnon_template_friend = 275,            /* -Wnon-template-friend */
  OPT_Wnon_virtual_dtor = 276,               /* -Wnon-virtual-dtor */
  OPT_Wnonnull = 277,                        /* -Wnonnull */
  OPT_Wnormalized_ = 278,                    /* -Wnormalized= */
  OPT_Wnull = 279,                           /* -Wnull */
  OPT_Wold_style_cast = 280,                 /* -Wold-style-cast */
  OPT_Wold_style_declaration = 281,          /* -Wold-style-declaration */
  OPT_Wold_style_definition = 282,           /* -Wold-style-definition */
  OPT_Wout_of_date = 283,                    /* -Wout-of-date */
  OPT_Wover_ann = 284,                       /* -Wover-ann */
  OPT_Woverflow = 285,                       /* -Woverflow */
  OPT_Woverlength_strings = 286,             /* -Woverlength-strings */
  OPT_Woverloaded_virtual = 287,             /* -Woverloaded-virtual */
  OPT_Woverride_init = 288,                  /* -Woverride-init */
  OPT_Wp_ = 289,                             /* -Wp, */
  OPT_Wpacked = 290,                         /* -Wpacked */
  OPT_Wpacked_bitfield_compat = 291,         /* -Wpacked-bitfield-compat */
  OPT_Wpadded = 292,                         /* -Wpadded */
  OPT_Wparam_assign = 293,                   /* -Wparam-assign */
  OPT_Wparentheses = 294,                    /* -Wparentheses */
  OPT_Wpkg_default_method = 295,             /* -Wpkg-default-method */
  OPT_Wpmf_conversions = 296,                /* -Wpmf-conversions */
  OPT_Wpointer_arith = 297,                  /* -Wpointer-arith */
  OPT_Wpointer_sign = 298,                   /* -Wpointer-sign */
  OPT_Wpointer_to_int_cast = 299,            /* -Wpointer-to-int-cast */
  OPT_Wpragmas = 300,                        /* -Wpragmas */
  OPT_Wproperty_assign_default = 301,        /* -Wproperty-assign-default */
  OPT_Wprotocol = 302,                       /* -Wprotocol */
  OPT_Wpsabi = 303,                          /* -Wpsabi */
  OPT_Wraw = 304,                            /* -Wraw */
  OPT_Wreal_q_constant = 305,                /* -Wreal-q-constant */
  OPT_Wredundant_decls = 306,                /* -Wredundant-decls */
  OPT_Wredundant_modifiers = 307,            /* -Wredundant-modifiers */
  OPT_Wreorder = 308,                        /* -Wreorder */
  OPT_Wreturn_type = 309,                    /* -Wreturn-type */
  OPT_Wselector = 310,                       /* -Wselector */
  OPT_Wsequence_point = 311,                 /* -Wsequence-point */
  OPT_Wserial = 312,                         /* -Wserial */
  OPT_Wshadow = 313,                         /* -Wshadow */
  OPT_Wsign_compare = 314,                   /* -Wsign-compare */
  OPT_Wsign_conversion = 315,                /* -Wsign-conversion */
  OPT_Wsign_promo = 316,                     /* -Wsign-promo */
  OPT_Wspecial_param_hiding = 317,           /* -Wspecial-param-hiding */
  OPT_Wstack_protector = 318,                /* -Wstack-protector */
  OPT_Wstatic_access = 319,                  /* -Wstatic-access */
  OPT_Wstatic_receiver = 320,                /* -Wstatic-receiver */
  OPT_Wstrict_aliasing = 321,                /* -Wstrict-aliasing */
  OPT_Wstrict_aliasing_ = 322,               /* -Wstrict-aliasing= */
  OPT_Wstrict_null_sentinel = 323,           /* -Wstrict-null-sentinel */
  OPT_Wstrict_overflow = 324,                /* -Wstrict-overflow */
  OPT_Wstrict_overflow_ = 325,               /* -Wstrict-overflow= */
  OPT_Wstrict_prototypes = 326,              /* -Wstrict-prototypes */
  OPT_Wstrict_selector_match = 327,          /* -Wstrict-selector-match */
  OPT_Wsuggest_attribute_const = 328,        /* -Wsuggest-attribute=const */
  OPT_Wsuggest_attribute_noreturn = 329,     /* -Wsuggest-attribute=noreturn */
  OPT_Wsuggest_attribute_pure = 330,         /* -Wsuggest-attribute=pure */
  OPT_Wsuppress = 331,                       /* -Wsuppress */
  OPT_Wsurprising = 332,                     /* -Wsurprising */
  OPT_Wswitch = 333,                         /* -Wswitch */
  OPT_Wswitch_default = 334,                 /* -Wswitch-default */
  OPT_Wswitch_enum = 335,                    /* -Wswitch-enum */
  OPT_Wsync_nand = 336,                      /* -Wsync-nand */
  OPT_Wsynth = 337,                          /* -Wsynth */
  OPT_Wsynthetic_access = 338,               /* -Wsynthetic-access */
  OPT_Wsystem_headers = 339,                 /* -Wsystem-headers */
  OPT_Wtabs = 340,                           /* -Wtabs */
  OPT_Wtasks = 341,                          /* -Wtasks */
  OPT_Wtraditional = 342,                    /* -Wtraditional */
  OPT_Wtraditional_conversion = 343,         /* -Wtraditional-conversion */
  OPT_Wtrampolines = 344,                    /* -Wtrampolines */
  OPT_Wtrigraphs = 345,                      /* -Wtrigraphs */
  OPT_Wtype_hiding = 346,                    /* -Wtype-hiding */
  OPT_Wtype_limits = 347,                    /* -Wtype-limits */
  OPT_Wuncheck = 348,                        /* -Wuncheck */
  OPT_Wundeclared_selector = 349,            /* -Wundeclared-selector */
  OPT_Wundef = 350,                          /* -Wundef */
  OPT_Wunderflow = 351,                      /* -Wunderflow */
  OPT_Wuninitialized = 352,                  /* -Wuninitialized */
  OPT_Wunknown_pragmas = 353,                /* -Wunknown-pragmas */
  OPT_Wunnecessary_else = 354,               /* -Wunnecessary-else */
  OPT_Wunqualified_field = 355,              /* -Wunqualified-field */
  /* OPT_Wunreachable_code = 356, */         /* -Wunreachable-code */
  OPT_Wunsafe_loop_optimizations = 357,      /* -Wunsafe-loop-optimizations */
  OPT_Wunsuffixed_float_constants = 358,     /* -Wunsuffixed-float-constants */
  OPT_Wunused = 359,                         /* -Wunused */
  OPT_Wunused_argument = 360,                /* -Wunused-argument */
  OPT_Wunused_but_set_parameter = 361,       /* -Wunused-but-set-parameter */
  OPT_Wunused_but_set_variable = 362,        /* -Wunused-but-set-variable */
  OPT_Wunused_dummy_argument = 363,          /* -Wunused-dummy-argument */
  OPT_Wunused_function = 364,                /* -Wunused-function */
  OPT_Wunused_import = 365,                  /* -Wunused-import */
  OPT_Wunused_label = 366,                   /* -Wunused-label */
  OPT_Wunused_local = 367,                   /* -Wunused-local */
  OPT_Wunused_macros = 368,                  /* -Wunused-macros */
  OPT_Wunused_parameter = 369,               /* -Wunused-parameter */
  OPT_Wunused_private = 370,                 /* -Wunused-private */
  OPT_Wunused_result = 371,                  /* -Wunused-result */
  OPT_Wunused_thrown = 372,                  /* -Wunused-thrown */
  OPT_Wunused_value = 373,                   /* -Wunused-value */
  OPT_Wunused_variable = 374,                /* -Wunused-variable */
  OPT_Wuseless_type_check = 375,             /* -Wuseless-type-check */
  OPT_Wvarargs_cast = 376,                   /* -Wvarargs-cast */
  OPT_Wvariadic_macros = 377,                /* -Wvariadic-macros */
  OPT_Wvla = 378,                            /* -Wvla */
  OPT_Wvolatile_register_var = 379,          /* -Wvolatile-register-var */
  OPT_Wwarning_token = 380,                  /* -Wwarning-token */
  OPT_Wwrite_strings = 381,                  /* -Wwrite-strings */
  OPT_Xassembler = 382,                      /* -Xassembler */
  OPT_Xlinker = 383,                         /* -Xlinker */
  OPT_Xpreprocessor = 384,                   /* -Xpreprocessor */
  OPT_Z = 385,                               /* -Z */
  OPT_ansi = 386,                            /* -ansi */
  OPT_aux_info = 387,                        /* -aux-info */
  /* OPT_aux_info_ = 388, */                 /* -aux-info= */
  OPT_auxbase = 389,                         /* -auxbase */
  OPT_auxbase_strip = 390,                   /* -auxbase-strip */
  /* OPT_bootclasspath = 391, */             /* -bootclasspath */
  OPT_c = 392,                               /* -c */
  /* OPT_classpath = 393, */                 /* -classpath */
  OPT_coverage = 394,                        /* -coverage */
  OPT_cpp = 395,                             /* -cpp */
  OPT_cpp_ = 396,                            /* -cpp= */
  OPT_d = 397,                               /* -d */
  OPT_dumpbase = 398,                        /* -dumpbase */
  OPT_dumpdir = 399,                         /* -dumpdir */
  OPT_dumpmachine = 400,                     /* -dumpmachine */
  OPT_dumpspecs = 401,                       /* -dumpspecs */
  OPT_dumpversion = 402,                     /* -dumpversion */
  OPT_e = 403,                               /* -e */
  /* OPT_encoding = 404, */                  /* -encoding */
  OPT_export_dynamic = 405,                  /* -export-dynamic */
  OPT_extdirs = 406,                         /* -extdirs */
  /* OPT_fCLASSPATH_ = 407, */               /* -fCLASSPATH= */
  OPT_fPIC = 408,                            /* -fPIC */
  OPT_fPIE = 409,                            /* -fPIE */
  OPT_fRTS_ = 410,                           /* -fRTS= */
  OPT_fabi_version_ = 411,                   /* -fabi-version= */
  OPT_faccess_control = 412,                 /* -faccess-control */
  OPT_falign_commons = 413,                  /* -falign-commons */
  OPT_falign_functions = 414,                /* -falign-functions */
  OPT_falign_functions_ = 415,               /* -falign-functions= */
  OPT_falign_jumps = 416,                    /* -falign-jumps */
  OPT_falign_jumps_ = 417,                   /* -falign-jumps= */
  OPT_falign_labels = 418,                   /* -falign-labels */
  OPT_falign_labels_ = 419,                  /* -falign-labels= */
  OPT_falign_loops = 420,                    /* -falign-loops */
  OPT_falign_loops_ = 421,                   /* -falign-loops= */
  OPT_fall_intrinsics = 422,                 /* -fall-intrinsics */
  /* OPT_fall_virtual = 423, */              /* -fall-virtual */
  OPT_fallow_leading_underscore = 424,       /* -fallow-leading-underscore */
  /* OPT_falt_external_templates = 425, */   /* -falt-external-templates */
  /* OPT_fargument_alias = 426, */           /* -fargument-alias */
  /* OPT_fargument_noalias = 427, */         /* -fargument-noalias */
  /* OPT_fargument_noalias_anything = 428, *//* -fargument-noalias-anything */
  /* OPT_fargument_noalias_global = 429, */  /* -fargument-noalias-global */
  OPT_fasm = 430,                            /* -fasm */
  OPT_fassert = 431,                         /* -fassert */
  OPT_fassociative_math = 432,               /* -fassociative-math */
  OPT_fassume_compiled = 433,                /* -fassume-compiled */
  OPT_fassume_compiled_ = 434,               /* -fassume-compiled= */
  OPT_fasynchronous_unwind_tables = 435,     /* -fasynchronous-unwind-tables */
  OPT_fauto_inc_dec = 436,                   /* -fauto-inc-dec */
  OPT_fautomatic = 437,                      /* -fautomatic */
  OPT_faux_classpath = 438,                  /* -faux-classpath */
  OPT_fbackslash = 439,                      /* -fbackslash */
  OPT_fbacktrace = 440,                      /* -fbacktrace */
  OPT_fblas_matmul_limit_ = 441,             /* -fblas-matmul-limit= */
  OPT_fbootclasspath_ = 442,                 /* -fbootclasspath= */
  OPT_fbootstrap_classes = 443,              /* -fbootstrap-classes */
  OPT_fbounds_check = 444,                   /* -fbounds-check */
  OPT_fbranch_count_reg = 445,               /* -fbranch-count-reg */
  OPT_fbranch_probabilities = 446,           /* -fbranch-probabilities */
  OPT_fbranch_target_load_optimize = 447,    /* -fbranch-target-load-optimize */
  OPT_fbranch_target_load_optimize2 = 448,   /* -fbranch-target-load-optimize2 */
  OPT_fbtr_bb_exclusive = 449,               /* -fbtr-bb-exclusive */
  OPT_fbuiltin = 450,                        /* -fbuiltin */
  OPT_fbuiltin_ = 451,                       /* -fbuiltin- */
  OPT_fcall_saved_ = 452,                    /* -fcall-saved- */
  OPT_fcall_used_ = 453,                     /* -fcall-used- */
  OPT_fcaller_saves = 454,                   /* -fcaller-saves */
  OPT_fcheck_array_temporaries = 455,        /* -fcheck-array-temporaries */
  OPT_fcheck_data_deps = 456,                /* -fcheck-data-deps */
  OPT_fcheck_new = 457,                      /* -fcheck-new */
  OPT_fcheck_references = 458,               /* -fcheck-references */
  OPT_fcheck_ = 459,                         /* -fcheck= */
  OPT_fclasspath_ = 460,                     /* -fclasspath= */
  OPT_fcoarray_ = 461,                       /* -fcoarray= */
  OPT_fcombine_stack_adjustments = 462,      /* -fcombine-stack-adjustments */
  OPT_fcommon = 463,                         /* -fcommon */
  OPT_fcompare_debug = 464,                  /* -fcompare-debug */
  OPT_fcompare_debug_second = 465,           /* -fcompare-debug-second */
  OPT_fcompare_debug_ = 466,                 /* -fcompare-debug= */
  OPT_fcompare_elim = 467,                   /* -fcompare-elim */
  OPT_fcompile_resource_ = 468,              /* -fcompile-resource= */
  OPT_fcond_mismatch = 469,                  /* -fcond-mismatch */
  OPT_fconserve_space = 470,                 /* -fconserve-space */
  OPT_fconserve_stack = 471,                 /* -fconserve-stack */
  OPT_fconstant_string_class_ = 472,         /* -fconstant-string-class= */
  OPT_fconstexpr_depth_ = 473,               /* -fconstexpr-depth= */
  OPT_fconvert_big_endian = 474,             /* -fconvert=big-endian */
  OPT_fconvert_little_endian = 475,          /* -fconvert=little-endian */
  OPT_fconvert_native = 476,                 /* -fconvert=native */
  OPT_fconvert_swap = 477,                   /* -fconvert=swap */
  OPT_fcprop_registers = 478,                /* -fcprop-registers */
  OPT_fcray_pointer = 479,                   /* -fcray-pointer */
  OPT_fcrossjumping = 480,                   /* -fcrossjumping */
  OPT_fcse_follow_jumps = 481,               /* -fcse-follow-jumps */
  /* OPT_fcse_skip_blocks = 482, */          /* -fcse-skip-blocks */
  OPT_fcx_fortran_rules = 483,               /* -fcx-fortran-rules */
  OPT_fcx_limited_range = 484,               /* -fcx-limited-range */
  OPT_fd_lines_as_code = 485,                /* -fd-lines-as-code */
  OPT_fd_lines_as_comments = 486,            /* -fd-lines-as-comments */
  OPT_fdata_sections = 487,                  /* -fdata-sections */
  OPT_fdbg_cnt_list = 488,                   /* -fdbg-cnt-list */
  OPT_fdbg_cnt_ = 489,                       /* -fdbg-cnt= */
  OPT_fdce = 490,                            /* -fdce */
  OPT_fdebug_prefix_map_ = 491,              /* -fdebug-prefix-map= */
  OPT_fdeduce_init_list = 492,               /* -fdeduce-init-list */
  OPT_fdefault_double_8 = 493,               /* -fdefault-double-8 */
  /* OPT_fdefault_inline = 494, */           /* -fdefault-inline */
  OPT_fdefault_integer_8 = 495,              /* -fdefault-integer-8 */
  OPT_fdefault_real_8 = 496,                 /* -fdefault-real-8 */
  OPT_fdefer_pop = 497,                      /* -fdefer-pop */
  OPT_fdelayed_branch = 498,                 /* -fdelayed-branch */
  OPT_fdelete_null_pointer_checks = 499,     /* -fdelete-null-pointer-checks */
  OPT_fdevirtualize = 500,                   /* -fdevirtualize */
  OPT_fdiagnostics_show_location_ = 501,     /* -fdiagnostics-show-location= */
  OPT_fdiagnostics_show_option = 502,        /* -fdiagnostics-show-option */
  OPT_fdirectives_only = 503,                /* -fdirectives-only */
  OPT_fdisable_assertions = 504,             /* -fdisable-assertions */
  OPT_fdisable_assertions_ = 505,            /* -fdisable-assertions= */
  OPT_fdollar_ok = 506,                      /* -fdollar-ok */
  OPT_fdollars_in_identifiers = 507,         /* -fdollars-in-identifiers */
  OPT_fdse = 508,                            /* -fdse */
  OPT_fdump_ = 509,                          /* -fdump- */
  OPT_fdump_core = 510,                      /* -fdump-core */
  OPT_fdump_final_insns = 511,               /* -fdump-final-insns */
  OPT_fdump_final_insns_ = 512,              /* -fdump-final-insns= */
  OPT_fdump_fortran_optimized = 513,         /* -fdump-fortran-optimized */
  OPT_fdump_fortran_original = 514,          /* -fdump-fortran-original */
  OPT_fdump_go_spec_ = 515,                  /* -fdump-go-spec= */
  OPT_fdump_noaddr = 516,                    /* -fdump-noaddr */
  OPT_fdump_parse_tree = 517,                /* -fdump-parse-tree */
  OPT_fdump_unnumbered = 518,                /* -fdump-unnumbered */
  OPT_fdump_unnumbered_links = 519,          /* -fdump-unnumbered-links */
  OPT_fdwarf2_cfi_asm = 520,                 /* -fdwarf2-cfi-asm */
  OPT_fearly_inlining = 521,                 /* -fearly-inlining */
  OPT_felide_constructors = 522,             /* -felide-constructors */
  OPT_feliminate_dwarf2_dups = 523,          /* -feliminate-dwarf2-dups */
  OPT_feliminate_unused_debug_symbols = 524, /* -feliminate-unused-debug-symbols */
  OPT_feliminate_unused_debug_types = 525,   /* -feliminate-unused-debug-types */
  OPT_femit_class_debug_always = 526,        /* -femit-class-debug-always */
  OPT_femit_class_file = 527,                /* -femit-class-file */
  OPT_femit_class_files = 528,               /* -femit-class-files */
  OPT_femit_struct_debug_baseonly = 529,     /* -femit-struct-debug-baseonly */
  OPT_femit_struct_debug_detailed_ = 530,    /* -femit-struct-debug-detailed= */
  OPT_femit_struct_debug_reduced = 531,      /* -femit-struct-debug-reduced */
  OPT_fenable_assertions = 532,              /* -fenable-assertions */
  OPT_fenable_assertions_ = 533,             /* -fenable-assertions= */
  OPT_fenable_icf_debug = 534,               /* -fenable-icf-debug */
  OPT_fencoding_ = 535,                      /* -fencoding= */
  OPT_fenforce_eh_specs = 536,               /* -fenforce-eh-specs */
  /* OPT_fenum_int_equiv = 537, */           /* -fenum-int-equiv */
  OPT_fexceptions = 538,                     /* -fexceptions */
  OPT_fexcess_precision_ = 539,              /* -fexcess-precision= */
  OPT_fexec_charset_ = 540,                  /* -fexec-charset= */
  OPT_fexpensive_optimizations = 541,        /* -fexpensive-optimizations */
  OPT_fextdirs_ = 542,                       /* -fextdirs= */
  OPT_fextended_identifiers = 543,           /* -fextended-identifiers */
  OPT_fexternal_blas = 544,                  /* -fexternal-blas */
  /* OPT_fexternal_templates = 545, */       /* -fexternal-templates */
  OPT_ff2c = 546,                            /* -ff2c */
  OPT_ffast_math = 547,                      /* -ffast-math */
  OPT_ffilelist_file = 548,                  /* -ffilelist-file */
  OPT_ffinite_math_only = 549,               /* -ffinite-math-only */
  OPT_ffixed_ = 550,                         /* -ffixed- */
  OPT_ffixed_form = 551,                     /* -ffixed-form */
  OPT_ffixed_line_length_ = 552,             /* -ffixed-line-length- */
  OPT_ffixed_line_length_none = 553,         /* -ffixed-line-length-none */
  OPT_ffloat_store = 554,                    /* -ffloat-store */
  OPT_ffor_scope = 555,                      /* -ffor-scope */
  /* OPT_fforce_addr = 556, */               /* -fforce-addr */
  OPT_fforce_classes_archive_check = 557,    /* -fforce-classes-archive-check */
  OPT_fforward_propagate = 558,              /* -fforward-propagate */
  OPT_ffp_contract_ = 559,                   /* -ffp-contract= */
  OPT_ffpe_trap_ = 560,                      /* -ffpe-trap= */
  OPT_ffree_form = 561,                      /* -ffree-form */
  OPT_ffree_line_length_ = 562,              /* -ffree-line-length- */
  OPT_ffree_line_length_none = 563,          /* -ffree-line-length-none */
  OPT_ffreestanding = 564,                   /* -ffreestanding */
  OPT_ffriend_injection = 565,               /* -ffriend-injection */
  OPT_ffunction_cse = 566,                   /* -ffunction-cse */
  OPT_ffunction_sections = 567,              /* -ffunction-sections */
  OPT_fgcse = 568,                           /* -fgcse */
  OPT_fgcse_after_reload = 569,              /* -fgcse-after-reload */
  OPT_fgcse_las = 570,                       /* -fgcse-las */
  OPT_fgcse_lm = 571,                        /* -fgcse-lm */
  OPT_fgcse_sm = 572,                        /* -fgcse-sm */
  OPT_fgnu_keywords = 573,                   /* -fgnu-keywords */
  OPT_fgnu_runtime = 574,                    /* -fgnu-runtime */
  OPT_fgnu89_inline = 575,                   /* -fgnu89-inline */
  OPT_fgo_dump_ = 576,                       /* -fgo-dump- */
  OPT_fgo_prefix_ = 577,                     /* -fgo-prefix= */
  OPT_fgraphite = 578,                       /* -fgraphite */
  OPT_fgraphite_identity = 579,              /* -fgraphite-identity */
  OPT_fguess_branch_probability = 580,       /* -fguess-branch-probability */
  /* OPT_fguiding_decls = 581, */            /* -fguiding-decls */
  /* OPT_fhandle_exceptions = 582, */        /* -fhandle-exceptions */
  OPT_fhash_synchronization = 583,           /* -fhash-synchronization */
  /* OPT_fhelp = 584, */                     /* -fhelp */
  /* OPT_fhelp_ = 585, */                    /* -fhelp= */
  /* OPT_fhonor_std = 586, */                /* -fhonor-std */
  OPT_fhonour_copts = 587,                   /* -fhonour-copts */
  OPT_fhosted = 588,                         /* -fhosted */
  /* OPT_fhuge_objects = 589, */             /* -fhuge-objects */
  OPT_fident = 590,                          /* -fident */
  OPT_fif_conversion = 591,                  /* -fif-conversion */
  OPT_fif_conversion2 = 592,                 /* -fif-conversion2 */
  OPT_fimplement_inlines = 593,              /* -fimplement-inlines */
  OPT_fimplicit_inline_templates = 594,      /* -fimplicit-inline-templates */
  OPT_fimplicit_none = 595,                  /* -fimplicit-none */
  OPT_fimplicit_templates = 596,             /* -fimplicit-templates */
  OPT_findirect_classes = 597,               /* -findirect-classes */
  OPT_findirect_dispatch = 598,              /* -findirect-dispatch */
  OPT_findirect_inlining = 599,              /* -findirect-inlining */
  OPT_finhibit_size_directive = 600,         /* -finhibit-size-directive */
  OPT_finit_character_ = 601,                /* -finit-character= */
  OPT_finit_integer_ = 602,                  /* -finit-integer= */
  OPT_finit_local_zero = 603,                /* -finit-local-zero */
  OPT_finit_logical_ = 604,                  /* -finit-logical= */
  OPT_finit_real_ = 605,                     /* -finit-real= */
  OPT_finline = 606,                         /* -finline */
  OPT_finline_functions = 607,               /* -finline-functions */
  OPT_finline_functions_called_once = 608,   /* -finline-functions-called-once */
  /* OPT_finline_limit_ = 609, */            /* -finline-limit- */
  OPT_finline_limit_ = 610,                  /* -finline-limit= */
  OPT_finline_small_functions = 611,         /* -finline-small-functions */
  OPT_finput_charset_ = 612,                 /* -finput-charset= */
  OPT_finstrument_functions = 613,           /* -finstrument-functions */
  OPT_finstrument_functions_exclude_file_list_ = 614,/* -finstrument-functions-exclude-file-list= */
  OPT_finstrument_functions_exclude_function_list_ = 615,/* -finstrument-functions-exclude-function-list= */
  OPT_fintrinsic_modules_path = 616,         /* -fintrinsic-modules-path */
  OPT_fipa_cp = 617,                         /* -fipa-cp */
  OPT_fipa_cp_clone = 618,                   /* -fipa-cp-clone */
  OPT_fipa_matrix_reorg = 619,               /* -fipa-matrix-reorg */
  OPT_fipa_profile = 620,                    /* -fipa-profile */
  OPT_fipa_pta = 621,                        /* -fipa-pta */
  OPT_fipa_pure_const = 622,                 /* -fipa-pure-const */
  OPT_fipa_reference = 623,                  /* -fipa-reference */
  OPT_fipa_sra = 624,                        /* -fipa-sra */
  OPT_fipa_struct_reorg = 625,               /* -fipa-struct-reorg */
  OPT_fira_algorithm_ = 626,                 /* -fira-algorithm= */
  OPT_fira_loop_pressure = 627,              /* -fira-loop-pressure */
  OPT_fira_region_ = 628,                    /* -fira-region= */
  OPT_fira_share_save_slots = 629,           /* -fira-share-save-slots */
  OPT_fira_share_spill_slots = 630,          /* -fira-share-spill-slots */
  OPT_fira_verbose_ = 631,                   /* -fira-verbose= */
  OPT_fivopts = 632,                         /* -fivopts */
  OPT_fjni = 633,                            /* -fjni */
  OPT_fjump_tables = 634,                    /* -fjump-tables */
  OPT_fkeep_inline_dllexport = 635,          /* -fkeep-inline-dllexport */
  OPT_fkeep_inline_functions = 636,          /* -fkeep-inline-functions */
  OPT_fkeep_static_consts = 637,             /* -fkeep-static-consts */
  /* OPT_flabels_ok = 638, */                /* -flabels-ok */
  OPT_flax_vector_conversions = 639,         /* -flax-vector-conversions */
  OPT_fleading_underscore = 640,             /* -fleading-underscore */
  OPT_floop_block = 641,                     /* -floop-block */
  OPT_floop_flatten = 642,                   /* -floop-flatten */
  OPT_floop_interchange = 643,               /* -floop-interchange */
  /* OPT_floop_optimize = 644, */            /* -floop-optimize */
  OPT_floop_parallelize_all = 645,           /* -floop-parallelize-all */
  OPT_floop_strip_mine = 646,                /* -floop-strip-mine */
  OPT_flto = 647,                            /* -flto */
  OPT_flto_compression_level_ = 648,         /* -flto-compression-level= */
  OPT_flto_partition_1to1 = 649,             /* -flto-partition=1to1 */
  OPT_flto_partition_balanced = 650,         /* -flto-partition=balanced */
  OPT_flto_partition_none = 651,             /* -flto-partition=none */
  OPT_flto_report = 652,                     /* -flto-report */
  OPT_flto_ = 653,                           /* -flto= */
  OPT_fltrans = 654,                         /* -fltrans */
  OPT_fltrans_output_list_ = 655,            /* -fltrans-output-list= */
  OPT_fmain_ = 656,                          /* -fmain= */
  OPT_fmath_errno = 657,                     /* -fmath-errno */
  OPT_fmax_array_constructor_ = 658,         /* -fmax-array-constructor= */
  OPT_fmax_errors_ = 659,                    /* -fmax-errors= */
  OPT_fmax_identifier_length_ = 660,         /* -fmax-identifier-length= */
  OPT_fmax_stack_var_size_ = 661,            /* -fmax-stack-var-size= */
  OPT_fmax_subrecord_length_ = 662,          /* -fmax-subrecord-length= */
  OPT_fmem_report = 663,                     /* -fmem-report */
  OPT_fmerge_all_constants = 664,            /* -fmerge-all-constants */
  OPT_fmerge_constants = 665,                /* -fmerge-constants */
  OPT_fmerge_debug_strings = 666,            /* -fmerge-debug-strings */
  OPT_fmessage_length_ = 667,                /* -fmessage-length= */
  OPT_fmodule_private = 668,                 /* -fmodule-private */
  OPT_fmodulo_sched = 669,                   /* -fmodulo-sched */
  OPT_fmodulo_sched_allow_regmoves = 670,    /* -fmodulo-sched-allow-regmoves */
  OPT_fmove_loop_invariants = 671,           /* -fmove-loop-invariants */
  OPT_fms_extensions = 672,                  /* -fms-extensions */
  OPT_fmudflap = 673,                        /* -fmudflap */
  OPT_fmudflapir = 674,                      /* -fmudflapir */
  OPT_fmudflapth = 675,                      /* -fmudflapth */
  /* OPT_fname_mangling_version_ = 676, */   /* -fname-mangling-version- */
  /* OPT_fnew_abi = 677, */                  /* -fnew-abi */
  OPT_fnext_runtime = 678,                   /* -fnext-runtime */
  OPT_fnil_receivers = 679,                  /* -fnil-receivers */
  OPT_fnon_call_exceptions = 680,            /* -fnon-call-exceptions */
  OPT_fnonansi_builtins = 681,               /* -fnonansi-builtins */
  /* OPT_fnonnull_objects = 682, */          /* -fnonnull-objects */
  OPT_fnothrow_opt = 683,                    /* -fnothrow-opt */
  OPT_fobjc_abi_version_ = 684,              /* -fobjc-abi-version= */
  OPT_fobjc_call_cxx_cdtors = 685,           /* -fobjc-call-cxx-cdtors */
  OPT_fobjc_direct_dispatch = 686,           /* -fobjc-direct-dispatch */
  OPT_fobjc_exceptions = 687,                /* -fobjc-exceptions */
  OPT_fobjc_gc = 688,                        /* -fobjc-gc */
  OPT_fobjc_nilcheck = 689,                  /* -fobjc-nilcheck */
  OPT_fobjc_sjlj_exceptions = 690,           /* -fobjc-sjlj-exceptions */
  OPT_fobjc_std_objc1 = 691,                 /* -fobjc-std=objc1 */
  OPT_fomit_frame_pointer = 692,             /* -fomit-frame-pointer */
  OPT_fopenmp = 693,                         /* -fopenmp */
  OPT_foperator_names = 694,                 /* -foperator-names */
  OPT_foptimize_register_move = 695,         /* -foptimize-register-move */
  OPT_foptimize_sibling_calls = 696,         /* -foptimize-sibling-calls */
  OPT_foptimize_static_class_initialization = 697,/* -foptimize-static-class-initialization */
  /* OPT_foptional_diags = 698, */           /* -foptional-diags */
  OPT_foutput_class_dir_ = 699,              /* -foutput-class-dir= */
  OPT_fpack_derived = 700,                   /* -fpack-derived */
  OPT_fpack_struct = 701,                    /* -fpack-struct */
  OPT_fpack_struct_ = 702,                   /* -fpack-struct= */
  OPT_fpartial_inlining = 703,               /* -fpartial-inlining */
  OPT_fpcc_struct_return = 704,              /* -fpcc-struct-return */
  OPT_fpch_deps = 705,                       /* -fpch-deps */
  OPT_fpch_preprocess = 706,                 /* -fpch-preprocess */
  OPT_fpeel_loops = 707,                     /* -fpeel-loops */
  OPT_fpeephole = 708,                       /* -fpeephole */
  OPT_fpeephole2 = 709,                      /* -fpeephole2 */
  OPT_fpermissive = 710,                     /* -fpermissive */
  OPT_fpic = 711,                            /* -fpic */
  OPT_fpie = 712,                            /* -fpie */
  OPT_fplan9_extensions = 713,               /* -fplan9-extensions */
  OPT_fplugin_arg_ = 714,                    /* -fplugin-arg- */
  OPT_fplugin_ = 715,                        /* -fplugin= */
  OPT_fpost_ipa_mem_report = 716,            /* -fpost-ipa-mem-report */
  OPT_fpre_ipa_mem_report = 717,             /* -fpre-ipa-mem-report */
  OPT_fpredictive_commoning = 718,           /* -fpredictive-commoning */
  OPT_fprefetch_loop_arrays = 719,           /* -fprefetch-loop-arrays */
  OPT_fpreprocessed = 720,                   /* -fpreprocessed */
  OPT_fpretty_templates = 721,               /* -fpretty-templates */
  OPT_fprofile = 722,                        /* -fprofile */
  OPT_fprofile_arcs = 723,                   /* -fprofile-arcs */
  OPT_fprofile_correction = 724,             /* -fprofile-correction */
  OPT_fprofile_dir_ = 725,                   /* -fprofile-dir= */
  OPT_fprofile_generate = 726,               /* -fprofile-generate */
  OPT_fprofile_generate_ = 727,              /* -fprofile-generate= */
  OPT_fprofile_use = 728,                    /* -fprofile-use */
  OPT_fprofile_use_ = 729,                   /* -fprofile-use= */
  OPT_fprofile_values = 730,                 /* -fprofile-values */
  OPT_fprotect_parens = 731,                 /* -fprotect-parens */
  OPT_frandom_seed = 732,                    /* -frandom-seed */
  OPT_frandom_seed_ = 733,                   /* -frandom-seed= */
  OPT_frange_check = 734,                    /* -frange-check */
  OPT_frealloc_lhs = 735,                    /* -frealloc-lhs */
  OPT_freciprocal_math = 736,                /* -freciprocal-math */
  OPT_frecord_gcc_switches = 737,            /* -frecord-gcc-switches */
  OPT_frecord_marker_4 = 738,                /* -frecord-marker=4 */
  OPT_frecord_marker_8 = 739,                /* -frecord-marker=8 */
  OPT_frecursive = 740,                      /* -frecursive */
  OPT_freduced_reflection = 741,             /* -freduced-reflection */
  OPT_freg_struct_return = 742,              /* -freg-struct-return */
  OPT_fregmove = 743,                        /* -fregmove */
  OPT_frename_registers = 744,               /* -frename-registers */
  OPT_freorder_blocks = 745,                 /* -freorder-blocks */
  OPT_freorder_blocks_and_partition = 746,   /* -freorder-blocks-and-partition */
  OPT_freorder_functions = 747,              /* -freorder-functions */
  OPT_frepack_arrays = 748,                  /* -frepack-arrays */
  OPT_freplace_objc_classes = 749,           /* -freplace-objc-classes */
  OPT_frepo = 750,                           /* -frepo */
  OPT_frequire_return_statement = 751,       /* -frequire-return-statement */
  OPT_frerun_cse_after_loop = 752,           /* -frerun-cse-after-loop */
  /* OPT_frerun_loop_opt = 753, */           /* -frerun-loop-opt */
  OPT_freschedule_modulo_scheduled_loops = 754,/* -freschedule-modulo-scheduled-loops */
  OPT_fresolution_ = 755,                    /* -fresolution= */
  OPT_frounding_math = 756,                  /* -frounding-math */
  OPT_frtti = 757,                           /* -frtti */
  OPT_fsaw_java_file = 758,                  /* -fsaw-java-file */
  OPT_fsched_critical_path_heuristic = 759,  /* -fsched-critical-path-heuristic */
  OPT_fsched_dep_count_heuristic = 760,      /* -fsched-dep-count-heuristic */
  OPT_fsched_group_heuristic = 761,          /* -fsched-group-heuristic */
  OPT_fsched_interblock = 762,               /* -fsched-interblock */
  OPT_fsched_last_insn_heuristic = 763,      /* -fsched-last-insn-heuristic */
  OPT_fsched_pressure = 764,                 /* -fsched-pressure */
  OPT_fsched_rank_heuristic = 765,           /* -fsched-rank-heuristic */
  OPT_fsched_spec = 766,                     /* -fsched-spec */
  OPT_fsched_spec_insn_heuristic = 767,      /* -fsched-spec-insn-heuristic */
  OPT_fsched_spec_load = 768,                /* -fsched-spec-load */
  OPT_fsched_spec_load_dangerous = 769,      /* -fsched-spec-load-dangerous */
  OPT_fsched_stalled_insns = 770,            /* -fsched-stalled-insns */
  OPT_fsched_stalled_insns_dep = 771,        /* -fsched-stalled-insns-dep */
  OPT_fsched_stalled_insns_dep_ = 772,       /* -fsched-stalled-insns-dep= */
  OPT_fsched_stalled_insns_ = 773,           /* -fsched-stalled-insns= */
  OPT_fsched_verbose_ = 774,                 /* -fsched-verbose= */
  OPT_fsched2_use_superblocks = 775,         /* -fsched2-use-superblocks */
  /* OPT_fsched2_use_traces = 776, */        /* -fsched2-use-traces */
  OPT_fschedule_insns = 777,                 /* -fschedule-insns */
  OPT_fschedule_insns2 = 778,                /* -fschedule-insns2 */
  OPT_fsecond_underscore = 779,              /* -fsecond-underscore */
  OPT_fsection_anchors = 780,                /* -fsection-anchors */
  /* OPT_fsee = 781, */                      /* -fsee */
  OPT_fsel_sched_pipelining = 782,           /* -fsel-sched-pipelining */
  OPT_fsel_sched_pipelining_outer_loops = 783,/* -fsel-sched-pipelining-outer-loops */
  OPT_fsel_sched_reschedule_pipelined = 784, /* -fsel-sched-reschedule-pipelined */
  OPT_fselective_scheduling = 785,           /* -fselective-scheduling */
  OPT_fselective_scheduling2 = 786,          /* -fselective-scheduling2 */
  OPT_fshort_double = 787,                   /* -fshort-double */
  OPT_fshort_enums = 788,                    /* -fshort-enums */
  OPT_fshort_wchar = 789,                    /* -fshort-wchar */
  OPT_fshow_column = 790,                    /* -fshow-column */
  OPT_fsign_zero = 791,                      /* -fsign-zero */
  OPT_fsignaling_nans = 792,                 /* -fsignaling-nans */
  OPT_fsigned_bitfields = 793,               /* -fsigned-bitfields */
  OPT_fsigned_char = 794,                    /* -fsigned-char */
  OPT_fsigned_zeros = 795,                   /* -fsigned-zeros */
  OPT_fsingle_precision_constant = 796,      /* -fsingle-precision-constant */
  OPT_fsource_filename_ = 797,               /* -fsource-filename= */
  OPT_fsource_ = 798,                        /* -fsource= */
  OPT_fsplit_ivs_in_unroller = 799,          /* -fsplit-ivs-in-unroller */
  OPT_fsplit_stack = 800,                    /* -fsplit-stack */
  OPT_fsplit_wide_types = 801,               /* -fsplit-wide-types */
  /* OPT_fsquangle = 802, */                 /* -fsquangle */
  /* OPT_fstack_check = 803, */              /* -fstack-check */
  OPT_fstack_check_ = 804,                   /* -fstack-check= */
  OPT_fstack_limit = 805,                    /* -fstack-limit */
  OPT_fstack_limit_register_ = 806,          /* -fstack-limit-register= */
  OPT_fstack_limit_symbol_ = 807,            /* -fstack-limit-symbol= */
  OPT_fstack_protector = 808,                /* -fstack-protector */
  OPT_fstack_protector_all = 809,            /* -fstack-protector-all */
  OPT_fstack_usage = 810,                    /* -fstack-usage */
  OPT_fstats = 811,                          /* -fstats */
  OPT_fstore_check = 812,                    /* -fstore-check */
  /* OPT_fstrength_reduce = 813, */          /* -fstrength-reduce */
  OPT_fstrict_aliasing = 814,                /* -fstrict-aliasing */
  OPT_fstrict_enums = 815,                   /* -fstrict-enums */
  OPT_fstrict_overflow = 816,                /* -fstrict-overflow */
  /* OPT_fstrict_prototype = 817, */         /* -fstrict-prototype */
  OPT_fstrict_volatile_bitfields = 818,      /* -fstrict-volatile-bitfields */
  OPT_fsyntax_only = 819,                    /* -fsyntax-only */
  OPT_ftabstop_ = 820,                       /* -ftabstop= */
  /* OPT_ftarget_help = 821, */              /* -ftarget-help */
  OPT_ftarget_ = 822,                        /* -ftarget= */
  /* OPT_ftemplate_depth_ = 823, */          /* -ftemplate-depth- */
  OPT_ftemplate_depth_ = 824,                /* -ftemplate-depth= */
  OPT_ftest_coverage = 825,                  /* -ftest-coverage */
  /* OPT_fthis_is_variable = 826, */         /* -fthis-is-variable */
  OPT_fthread_jumps = 827,                   /* -fthread-jumps */
  OPT_fthreadsafe_statics = 828,             /* -fthreadsafe-statics */
  OPT_ftime_report = 829,                    /* -ftime-report */
  OPT_ftls_model_ = 830,                     /* -ftls-model= */
  OPT_ftoplevel_reorder = 831,               /* -ftoplevel-reorder */
  OPT_ftracer = 832,                         /* -ftracer */
  OPT_ftrapping_math = 833,                  /* -ftrapping-math */
  OPT_ftrapv = 834,                          /* -ftrapv */
  OPT_ftree_bit_ccp = 835,                   /* -ftree-bit-ccp */
  OPT_ftree_builtin_call_dce = 836,          /* -ftree-builtin-call-dce */
  OPT_ftree_ccp = 837,                       /* -ftree-ccp */
  OPT_ftree_ch = 838,                        /* -ftree-ch */
  OPT_ftree_copy_prop = 839,                 /* -ftree-copy-prop */
  OPT_ftree_copyrename = 840,                /* -ftree-copyrename */
  OPT_ftree_cselim = 841,                    /* -ftree-cselim */
  OPT_ftree_dce = 842,                       /* -ftree-dce */
  OPT_ftree_dominator_opts = 843,            /* -ftree-dominator-opts */
  OPT_ftree_dse = 844,                       /* -ftree-dse */
  OPT_ftree_forwprop = 845,                  /* -ftree-forwprop */
  OPT_ftree_fre = 846,                       /* -ftree-fre */
  OPT_ftree_loop_distribute_patterns = 847,  /* -ftree-loop-distribute-patterns */
  OPT_ftree_loop_distribution = 848,         /* -ftree-loop-distribution */
  OPT_ftree_loop_if_convert = 849,           /* -ftree-loop-if-convert */
  OPT_ftree_loop_if_convert_stores = 850,    /* -ftree-loop-if-convert-stores */
  OPT_ftree_loop_im = 851,                   /* -ftree-loop-im */
  OPT_ftree_loop_ivcanon = 852,              /* -ftree-loop-ivcanon */
  /* OPT_ftree_loop_linear = 853, */         /* -ftree-loop-linear */
  OPT_ftree_loop_optimize = 854,             /* -ftree-loop-optimize */
  OPT_ftree_lrs = 855,                       /* -ftree-lrs */
  OPT_ftree_parallelize_loops_ = 856,        /* -ftree-parallelize-loops= */
  OPT_ftree_phiprop = 857,                   /* -ftree-phiprop */
  OPT_ftree_pre = 858,                       /* -ftree-pre */
  OPT_ftree_pta = 859,                       /* -ftree-pta */
  OPT_ftree_reassoc = 860,                   /* -ftree-reassoc */
  /* OPT_ftree_salias = 861, */              /* -ftree-salias */
  OPT_ftree_scev_cprop = 862,                /* -ftree-scev-cprop */
  OPT_ftree_sink = 863,                      /* -ftree-sink */
  OPT_ftree_slp_vectorize = 864,             /* -ftree-slp-vectorize */
  OPT_ftree_sra = 865,                       /* -ftree-sra */
  /* OPT_ftree_store_ccp = 866, */           /* -ftree-store-ccp */
  /* OPT_ftree_store_copy_prop = 867, */     /* -ftree-store-copy-prop */
  OPT_ftree_switch_conversion = 868,         /* -ftree-switch-conversion */
  OPT_ftree_ter = 869,                       /* -ftree-ter */
  OPT_ftree_vect_loop_version = 870,         /* -ftree-vect-loop-version */
  OPT_ftree_vectorize = 871,                 /* -ftree-vectorize */
  OPT_ftree_vectorizer_verbose_ = 872,       /* -ftree-vectorizer-verbose= */
  OPT_ftree_vrp = 873,                       /* -ftree-vrp */
  OPT_funderscoring = 874,                   /* -funderscoring */
  OPT_funit_at_a_time = 875,                 /* -funit-at-a-time */
  OPT_funroll_all_loops = 876,               /* -funroll-all-loops */
  OPT_funroll_loops = 877,                   /* -funroll-loops */
  OPT_funsafe_loop_optimizations = 878,      /* -funsafe-loop-optimizations */
  OPT_funsafe_math_optimizations = 879,      /* -funsafe-math-optimizations */
  OPT_funsigned_bitfields = 880,             /* -funsigned-bitfields */
  OPT_funsigned_char = 881,                  /* -funsigned-char */
  OPT_funswitch_loops = 882,                 /* -funswitch-loops */
  OPT_funwind_tables = 883,                  /* -funwind-tables */
  OPT_fuse_atomic_builtins = 884,            /* -fuse-atomic-builtins */
  OPT_fuse_boehm_gc = 885,                   /* -fuse-boehm-gc */
  OPT_fuse_cxa_atexit = 886,                 /* -fuse-cxa-atexit */
  OPT_fuse_cxa_get_exception_ptr = 887,      /* -fuse-cxa-get-exception-ptr */
  OPT_fuse_divide_subroutine = 888,          /* -fuse-divide-subroutine */
  OPT_fuse_linker_plugin = 889,              /* -fuse-linker-plugin */
  OPT_fvar_tracking = 890,                   /* -fvar-tracking */
  OPT_fvar_tracking_assignments = 891,       /* -fvar-tracking-assignments */
  OPT_fvar_tracking_assignments_toggle = 892,/* -fvar-tracking-assignments-toggle */
  OPT_fvar_tracking_uninit = 893,            /* -fvar-tracking-uninit */
  OPT_fvariable_expansion_in_unroller = 894, /* -fvariable-expansion-in-unroller */
  OPT_fvect_cost_model = 895,                /* -fvect-cost-model */
  OPT_fverbose_asm = 896,                    /* -fverbose-asm */
  /* OPT_fversion = 897, */                  /* -fversion */
  OPT_fvisibility_inlines_hidden = 898,      /* -fvisibility-inlines-hidden */
  OPT_fvisibility_ms_compat = 899,           /* -fvisibility-ms-compat */
  OPT_fvisibility_ = 900,                    /* -fvisibility= */
  OPT_fvpt = 901,                            /* -fvpt */
  /* OPT_fvtable_gc = 902, */                /* -fvtable-gc */
  /* OPT_fvtable_thunks = 903, */            /* -fvtable-thunks */
  OPT_fweak = 904,                           /* -fweak */
  OPT_fweb = 905,                            /* -fweb */
  OPT_fwhole_file = 906,                     /* -fwhole-file */
  OPT_fwhole_program = 907,                  /* -fwhole-program */
  OPT_fwide_exec_charset_ = 908,             /* -fwide-exec-charset= */
  OPT_fworking_directory = 909,              /* -fworking-directory */
  OPT_fwpa = 910,                            /* -fwpa */
  OPT_fwrapv = 911,                          /* -fwrapv */
  /* OPT_fxref = 912, */                     /* -fxref */
  OPT_fzee = 913,                            /* -fzee */
  OPT_fzero_initialized_in_bss = 914,        /* -fzero-initialized-in-bss */
  OPT_fzero_link = 915,                      /* -fzero-link */
  OPT_g = 916,                               /* -g */
  OPT_gant = 917,                            /* -gant */
  OPT_gcoff = 918,                           /* -gcoff */
  OPT_gdwarf_ = 919,                         /* -gdwarf- */
  OPT_gen_decls = 920,                       /* -gen-decls */
  OPT_ggdb = 921,                            /* -ggdb */
  OPT_gnat = 922,                            /* -gnat */
  OPT_gnatO = 923,                           /* -gnatO */
  OPT_gno_strict_dwarf = 924,                /* -gno-strict-dwarf */
  OPT_gstabs = 925,                          /* -gstabs */
  OPT_gstabs_ = 926,                         /* -gstabs+ */
  OPT_gstrict_dwarf = 927,                   /* -gstrict-dwarf */
  OPT_gtoggle = 928,                         /* -gtoggle */
  OPT_gvms = 929,                            /* -gvms */
  OPT_gxcoff = 930,                          /* -gxcoff */
  OPT_gxcoff_ = 931,                         /* -gxcoff+ */
  OPT_h = 932,                               /* -h */
  OPT_idirafter = 933,                       /* -idirafter */
  OPT_imacros = 934,                         /* -imacros */
  OPT_imultiarch = 935,                      /* -imultiarch */
  OPT_imultilib = 936,                       /* -imultilib */
  OPT_include = 937,                         /* -include */
  OPT_iplugindir_ = 938,                     /* -iplugindir= */
  OPT_iprefix = 939,                         /* -iprefix */
  OPT_iquote = 940,                          /* -iquote */
  OPT_isysroot = 941,                        /* -isysroot */
  OPT_isystem = 942,                         /* -isystem */
  OPT_iwithprefix = 943,                     /* -iwithprefix */
  OPT_iwithprefixbefore = 944,               /* -iwithprefixbefore */
  OPT_k8 = 945,                              /* -k8 */
  OPT_l = 946,                               /* -l */
  OPT_lang_asm = 947,                        /* -lang-asm */
  OPT_mabi_ = 948,                           /* -mabi= */
  OPT_mabicalls = 949,                       /* -mabicalls */
  OPT_mad = 950,                             /* -mad */
  OPT_mandroid = 951,                        /* -mandroid */
  OPT_march_ = 952,                          /* -march= */
  OPT_mbionic = 953,                         /* -mbionic */
  OPT_mbranch_cost_ = 954,                   /* -mbranch-cost= */
  OPT_mbranch_likely = 955,                  /* -mbranch-likely */
  OPT_mcheck_zero_division = 956,            /* -mcheck-zero-division */
  OPT_mcode_readable_ = 957,                 /* -mcode-readable= */
  OPT_mdebug = 958,                          /* -mdebug */
  OPT_mdebugd = 959,                         /* -mdebugd */
  OPT_mdivide_breaks = 960,                  /* -mdivide-breaks */
  OPT_mdivide_traps = 961,                   /* -mdivide-traps */
  OPT_mdmx = 962,                            /* -mdmx */
  OPT_mdouble_float = 963,                   /* -mdouble-float */
  OPT_mdsp = 964,                            /* -mdsp */
  OPT_mdspr2 = 965,                          /* -mdspr2 */
  OPT_meb = 966,                             /* -meb */
  OPT_mel = 967,                             /* -mel */
  OPT_membedded_data = 968,                  /* -membedded-data */
  OPT_mexplicit_relocs = 969,                /* -mexplicit-relocs */
  OPT_mextern_sdata = 970,                   /* -mextern-sdata */
  OPT_mfix_r10000 = 971,                     /* -mfix-r10000 */
  OPT_mfix_r4000 = 972,                      /* -mfix-r4000 */
  OPT_mfix_r4400 = 973,                      /* -mfix-r4400 */
  OPT_mfix_sb1 = 974,                        /* -mfix-sb1 */
  OPT_mfix_vr4120 = 975,                     /* -mfix-vr4120 */
  OPT_mfix_vr4130 = 976,                     /* -mfix-vr4130 */
  OPT_mfix4300 = 977,                        /* -mfix4300 */
  OPT_mflip_mips16 = 978,                    /* -mflip-mips16 */
  OPT_mflush_func_ = 979,                    /* -mflush-func= */
  OPT_mfp_exceptions = 980,                  /* -mfp-exceptions */
  OPT_mfp32 = 981,                           /* -mfp32 */
  OPT_mfp64 = 982,                           /* -mfp64 */
  OPT_mfused_madd = 983,                     /* -mfused-madd */
  OPT_mglibc = 984,                          /* -mglibc */
  OPT_mgp32 = 985,                           /* -mgp32 */
  OPT_mgp64 = 986,                           /* -mgp64 */
  OPT_mgpopt = 987,                          /* -mgpopt */
  OPT_mhard_float = 988,                     /* -mhard-float */
  OPT_minterlink_mips16 = 989,               /* -minterlink-mips16 */
  OPT_mips = 990,                            /* -mips */
  OPT_mips16 = 991,                          /* -mips16 */
  OPT_mips3d = 992,                          /* -mips3d */
  OPT_mllsc = 993,                           /* -mllsc */
  OPT_mlocal_sdata = 994,                    /* -mlocal-sdata */
  OPT_mlong_calls = 995,                     /* -mlong-calls */
  OPT_mlong32 = 996,                         /* -mlong32 */
  OPT_mlong64 = 997,                         /* -mlong64 */
  OPT_mmcount_ra_address = 998,              /* -mmcount-ra-address */
  OPT_mmemcpy = 999,                         /* -mmemcpy */
  OPT_mmips_tfile = 1000,                    /* -mmips-tfile */
  OPT_mmt = 1001,                            /* -mmt */
  OPT_mno_float = 1002,                      /* -mno-float */
  OPT_mno_flush_func = 1003,                 /* -mno-flush-func */
  OPT_mno_mdmx = 1004,                       /* -mno-mdmx */
  OPT_mno_mips16 = 1005,                     /* -mno-mips16 */
  OPT_mno_mips3d = 1006,                     /* -mno-mips3d */
  OPT_mpaired_single = 1007,                 /* -mpaired-single */
  OPT_mplt = 1008,                           /* -mplt */
  OPT_mr10k_cache_barrier_ = 1009,           /* -mr10k-cache-barrier= */
  OPT_mrelax_pic_calls = 1010,               /* -mrelax-pic-calls */
  OPT_mshared = 1011,                        /* -mshared */
  OPT_msingle_float = 1012,                  /* -msingle-float */
  OPT_msmartmips = 1013,                     /* -msmartmips */
  OPT_msoft_float = 1014,                    /* -msoft-float */
  OPT_msplit_addresses = 1015,               /* -msplit-addresses */
  OPT_msym32 = 1016,                         /* -msym32 */
  OPT_msynci = 1017,                         /* -msynci */
  OPT_mtune_ = 1018,                         /* -mtune= */
  OPT_muclibc = 1019,                        /* -muclibc */
  OPT_muninit_const_in_rodata = 1020,        /* -muninit-const-in-rodata */
  OPT_mvr4130_align = 1021,                  /* -mvr4130-align */
  OPT_mxgot = 1022,                          /* -mxgot */
  OPT_n = 1023,                              /* -n */
  OPT_no_canonical_prefixes = 1024,          /* -no-canonical-prefixes */
  OPT_no_integrated_cpp = 1025,              /* -no-integrated-cpp */
  OPT_noasmopt = 1026,                       /* -noasmopt */
  OPT_nocpp = 1027,                          /* -nocpp */
  OPT_nodefaultlibs = 1028,                  /* -nodefaultlibs */
  OPT_nostartfiles = 1029,                   /* -nostartfiles */
  OPT_nostdinc = 1030,                       /* -nostdinc */
  OPT_nostdinc__ = 1031,                     /* -nostdinc++ */
  OPT_nostdlib = 1032,                       /* -nostdlib */
  OPT_o = 1033,                              /* -o */
  OPT_p = 1034,                              /* -p */
  OPT_pass_exit_codes = 1035,                /* -pass-exit-codes */
  OPT_pedantic = 1036,                       /* -pedantic */
  OPT_pedantic_errors = 1037,                /* -pedantic-errors */
  OPT_pg = 1038,                             /* -pg */
  OPT_pie = 1039,                            /* -pie */
  OPT_pipe = 1040,                           /* -pipe */
  OPT_posix = 1041,                          /* -posix */
  OPT_print_file_name_ = 1042,               /* -print-file-name= */
  OPT_print_libgcc_file_name = 1043,         /* -print-libgcc-file-name */
  OPT_print_multi_directory = 1044,          /* -print-multi-directory */
  OPT_print_multi_lib = 1045,                /* -print-multi-lib */
  OPT_print_multi_os_directory = 1046,       /* -print-multi-os-directory */
  OPT_print_multiarch = 1047,                /* -print-multiarch */
  OPT_print_objc_runtime_info = 1048,        /* -print-objc-runtime-info */
  OPT_print_prog_name_ = 1049,               /* -print-prog-name= */
  OPT_print_search_dirs = 1050,              /* -print-search-dirs */
  OPT_print_sysroot = 1051,                  /* -print-sysroot */
  OPT_print_sysroot_headers_suffix = 1052,   /* -print-sysroot-headers-suffix */
  OPT_profile = 1053,                        /* -profile */
  OPT_pthread = 1054,                        /* -pthread */
  OPT_quiet = 1055,                          /* -quiet */
  OPT_r = 1056,                              /* -r */
  OPT_rdynamic = 1057,                       /* -rdynamic */
  OPT_remap = 1058,                          /* -remap */
  OPT_s = 1059,                              /* -s */
  OPT_s_bc_abi = 1060,                       /* -s-bc-abi */
  OPT_save_temps = 1061,                     /* -save-temps */
  OPT_save_temps_ = 1062,                    /* -save-temps= */
  OPT_shared = 1063,                         /* -shared */
  OPT_shared_libgcc = 1064,                  /* -shared-libgcc */
  /* OPT_specs = 1065, */                    /* -specs */
  OPT_specs_ = 1066,                         /* -specs= */
  OPT_static = 1067,                         /* -static */
  OPT_static_libgcc = 1068,                  /* -static-libgcc */
  OPT_static_libgcj = 1069,                  /* -static-libgcj */
  OPT_static_libgfortran = 1070,             /* -static-libgfortran */
  OPT_static_libgo = 1071,                   /* -static-libgo */
  OPT_static_libstdc__ = 1072,               /* -static-libstdc++ */
  /* OPT_std_c__03 = 1073, */                /* -std=c++03 */
  OPT_std_c__0x = 1074,                      /* -std=c++0x */
  OPT_std_c__98 = 1075,                      /* -std=c++98 */
  OPT_std_c1x = 1076,                        /* -std=c1x */
  /* OPT_std_c89 = 1077, */                  /* -std=c89 */
  OPT_std_c90 = 1078,                        /* -std=c90 */
  OPT_std_c99 = 1079,                        /* -std=c99 */
  /* OPT_std_c9x = 1080, */                  /* -std=c9x */
  OPT_std_f2003 = 1081,                      /* -std=f2003 */
  OPT_std_f2008 = 1082,                      /* -std=f2008 */
  OPT_std_f95 = 1083,                        /* -std=f95 */
  OPT_std_gnu = 1084,                        /* -std=gnu */
  OPT_std_gnu__0x = 1085,                    /* -std=gnu++0x */
  OPT_std_gnu__98 = 1086,                    /* -std=gnu++98 */
  OPT_std_gnu1x = 1087,                      /* -std=gnu1x */
  /* OPT_std_gnu89 = 1088, */                /* -std=gnu89 */
  OPT_std_gnu90 = 1089,                      /* -std=gnu90 */
  OPT_std_gnu99 = 1090,                      /* -std=gnu99 */
  /* OPT_std_gnu9x = 1091, */                /* -std=gnu9x */
  /* OPT_std_iso9899_1990 = 1092, */         /* -std=iso9899:1990 */
  OPT_std_iso9899_199409 = 1093,             /* -std=iso9899:199409 */
  /* OPT_std_iso9899_1999 = 1094, */         /* -std=iso9899:1999 */
  /* OPT_std_iso9899_199x = 1095, */         /* -std=iso9899:199x */
  OPT_std_legacy = 1096,                     /* -std=legacy */
  OPT_symbolic = 1097,                       /* -symbolic */
  OPT_t = 1098,                              /* -t */
  OPT_time = 1099,                           /* -time */
  OPT_time_ = 1100,                          /* -time= */
  OPT_tno_android_cc = 1101,                 /* -tno-android-cc */
  OPT_tno_android_ld = 1102,                 /* -tno-android-ld */
  OPT_traditional = 1103,                    /* -traditional */
  OPT_traditional_cpp = 1104,                /* -traditional-cpp */
  OPT_trigraphs = 1105,                      /* -trigraphs */
  OPT_u = 1106,                              /* -u */
  OPT_undef = 1107,                          /* -undef */
  OPT_v = 1108,                              /* -v */
  OPT_version = 1109,                        /* -version */
  OPT_w = 1110,                              /* -w */
  OPT_wrapper = 1111,                        /* -wrapper */
  OPT_x = 1112,                              /* -x */
  OPT_z = 1113,                              /* -z */
  N_OPTS,
  OPT_SPECIAL_unknown,
  OPT_SPECIAL_ignore,
  OPT_SPECIAL_program_name,
  OPT_SPECIAL_input_file
};

#endif /* OPTIONS_H */
